import 'package:dart_twitter_api/api/tweets/tweet_service.dart';
import 'package:dart_twitter_api/twitter_api.dart';
import 'package:http/http.dart';
import 'package:mockito/mockito.dart';
import 'package:test/test.dart';

import 'mock_client.dart';

void main() async {
  test('`update` parses tweet object from response', () async {
    final mockClient = MockClient();

    when(mockClient.post(
      Uri.https('api.twitter.com', '1.1/statuses/update.json'),
      body: anyNamed('body'),
    )).thenAnswer((_) async => Response(_updateResponse, 200));

    final tweetService = TweetService(client: mockClient);

    final tweet = await tweetService.update(status: 'hello world');

    expect(tweet, isA<Tweet>());
  });

  test('`destroy` parses tweet object from response', () async {
    final mockClient = MockClient();

    when(mockClient.post(
      Uri.https('api.twitter.com', '1.1/statuses/destroy/1236345.json'),
      body: anyNamed('body'),
    )).thenAnswer((_) async => Response(_destroyResponse, 200));

    final tweetService = TweetService(client: mockClient);

    final tweet = await tweetService.destroy(id: '1236345');

    expect(tweet, isA<Tweet>());
  });

  test('`show` parses tweet object from response', () async {
    final mockClient = MockClient();

    when(mockClient.get(
      Uri.https(
        'api.twitter.com',
        '1.1/statuses/show.json',
        {'tweet_mode': 'extended', 'id': '123'},
      ),
    )).thenAnswer((_) async => Response(_showResponse, 200));

    final tweetService = TweetService(client: mockClient);

    final tweet = await tweetService.show(id: '123');

    expect(tweet, isA<Tweet>());
  });

  test('`retweet` parses tweet object from response', () async {
    final mockClient = MockClient();

    when(mockClient.post(
      Uri.https('api.twitter.com', '1.1/statuses/retweet/6453645.json'),
      body: anyNamed('body'),
    )).thenAnswer((_) async => Response(_retweetResponse, 200));

    final tweetService = TweetService(client: mockClient);

    final tweet = await tweetService.retweet(id: '6453645');

    expect(tweet, isA<Tweet>());
  });

  test('`unretweet` parses tweet object from response', () async {
    final mockClient = MockClient();

    when(mockClient.post(
      Uri.https('api.twitter.com', '1.1/statuses/unretweet/7657876.json'),
      body: anyNamed('body'),
    )).thenAnswer((_) async => Response(_unretweetResponse, 200));

    final tweetService = TweetService(client: mockClient);

    final tweet = await tweetService.unretweet(id: '7657876');

    expect(tweet, isA<Tweet>());
  });

  test('`retweets` parses list of tweet objects from response', () async {
    final mockClient = MockClient();

    when(mockClient.get(
      Uri.https(
        'api.twitter.com',
        '1.1/statuses/retweets/912456.json',
        {'tweet_mode': 'extended'},
      ),
    )).thenAnswer((_) async => Response(_retweetsResponse, 200));

    final tweetService = TweetService(client: mockClient);

    final tweet = await tweetService.retweets(id: '912456');

    expect(tweet, isA<List<Tweet>>());
  });

  test('`retweetsOfMe` parses list of tweet objects from response', () async {
    final mockClient = MockClient();

    when(mockClient.get(
      Uri.https(
        'api.twitter.com',
        '1.1/statuses/retweets_of_me.json',
        {'tweet_mode': 'extended'},
      ),
    )).thenAnswer((_) async => Response(_retweetsOfMeResponse, 200));

    final tweetService = TweetService(client: mockClient);

    final tweet = await tweetService.retweetsOfMe();

    expect(tweet, isA<List<Tweet>>());
  });

  test('`createFavorite` parses tweet object from response', () async {
    final mockClient = MockClient();

    when(mockClient.post(
      Uri.https('api.twitter.com', '1.1/favorites/create.json'),
      body: anyNamed('body'),
    )).thenAnswer((_) async => Response(_createFavoriteResponse, 200));

    final tweetService = TweetService(client: mockClient);

    final tweet = await tweetService.createFavorite(id: '54367');

    expect(tweet, isA<Tweet>());
  });

  test('`destroyFavorite` parses tweet object from response', () async {
    final mockClient = MockClient();

    when(mockClient.post(
      Uri.https('api.twitter.com', '1.1/favorites/destroy.json'),
      body: anyNamed('body'),
    )).thenAnswer((_) async => Response(_destroyFavoriteResponse, 200));

    final tweetService = TweetService(client: mockClient);

    final tweet = await tweetService.destroyFavorite(id: '54367');

    expect(tweet, isA<Tweet>());
  });

  test('`listFavorites` parses list of tweet objects from response', () async {
    final mockClient = MockClient();

    when(mockClient.get(
      Uri.https(
        'api.twitter.com',
        '1.1/favorites/list.json',
        {'tweet_mode': 'extended'},
      ),
    )).thenAnswer((_) async => Response(_listFavoritesResponse, 200));

    final tweetService = TweetService(client: mockClient);

    final tweet = await tweetService.listFavorites();

    expect(tweet, isA<List<Tweet>>());
  });
}

const _updateResponse =
    '''{\"created_at\":\"Wed Jun 03 20:26:54 +0000 2020\",\"id\":1268278004767129601,\"id_str\":\"1268278004767129601\",\"full_text\":\"uwu\",\"truncated\":false,\"display_text_range\":[0,3],\"entities\":{\"hashtags\":[],\"symbols\":[],\"user_mentions\":[],\"urls\":[]},\"source\":\"\\u003ca href=\\\"http:\\/\\/robertodoering.com\\\" rel=\\\"nofollow\\\"\\u003eDart Wrapper\\u003c\\/a\\u003e\",\"in_reply_to_status_id\":null,\"in_reply_to_status_id_str\":null,\"in_reply_to_user_id\":null,\"in_reply_to_user_id_str\":null,\"in_reply_to_screen_name\":null,\"user\":{\"id\":1068105113284300800,\"id_str\":\"1068105113284300800\",\"name\":\"Harpy App\",\"screen_name\":\"harpy_app\",\"location\":\"North Pole, AK\",\"description\":\"please don't hurt me\",\"url\":\"https:\\/\\/t.co\\/cHZdP4MpC4\",\"entities\":{\"url\":{\"urls\":[{\"url\":\"https:\\/\\/t.co\\/cHZdP4MpC4\",\"expanded_url\":\"http:\\/\\/google.com\",\"display_url\":\"google.com\",\"indices\":[0,23]}]},\"description\":{\"urls\":[]}},\"protected\":false,\"followers_count\":1,\"friends_count\":10,\"listed_count\":0,\"created_at\":\"Thu Nov 29 11:31:18 +0000 2018\",\"favourites_count\":14,\"utc_offset\":null,\"time_zone\":null,\"geo_enabled\":false,\"verified\":false,\"statuses_count\":46,\"lang\":null,\"contributors_enabled\":false,\"is_translator\":false,\"is_translation_enabled\":false,\"profile_background_color\":\"000000\",\"profile_background_image_url\":\"http:\\/\\/abs.twimg.com\\/images\\/themes\\/theme1\\/bg.png\",\"profile_background_image_url_https\":\"https:\\/\\/abs.twimg.com\\/images\\/themes\\/theme1\\/bg.png\",\"profile_background_tile\":false,\"profile_image_url\":\"http:\\/\\/abs.twimg.com\\/sticky\\/default_profile_images\\/default_profile_normal.png\",\"profile_image_url_https\":\"https:\\/\\/abs.twimg.com\\/sticky\\/default_profile_images\\/default_profile_normal.png\",\"profile_link_color\":\"981CEB\",\"profile_sidebar_border_color\":\"000000\",\"profile_sidebar_fill_color\":\"000000\",\"profile_text_color\":\"000000\",\"profile_use_background_image\":false,\"has_extended_profile\":true,\"default_profile\":false,\"default_profile_image\":true,\"following\":false,\"follow_request_sent\":false,\"notifications\":false,\"translator_type\":\"none\"},\"geo\":null,\"coordinates\":null,\"place\":null,\"contributors\":null,\"is_quote_status\":false,\"retweet_count\":0,\"favorite_count\":0,\"favorited\":false,\"retweeted\":false,\"lang\":\"und\"}''';

const _destroyResponse =
    '''{\"created_at\":\"Wed Jun 03 20:26:54 +0000 2020\",\"id\":1268278004767129601,\"id_str\":\"1268278004767129601\",\"full_text\":\"uwu\",\"truncated\":false,\"display_text_range\":[0,3],\"entities\":{\"hashtags\":[],\"symbols\":[],\"user_mentions\":[],\"urls\":[]},\"source\":\"\\u003ca href=\\\"http:\\/\\/robertodoering.com\\\" rel=\\\"nofollow\\\"\\u003eDart Wrapper\\u003c\\/a\\u003e\",\"in_reply_to_status_id\":null,\"in_reply_to_status_id_str\":null,\"in_reply_to_user_id\":null,\"in_reply_to_user_id_str\":null,\"in_reply_to_screen_name\":null,\"user\":{\"id\":1068105113284300800,\"id_str\":\"1068105113284300800\",\"name\":\"Harpy App\",\"screen_name\":\"harpy_app\",\"location\":\"North Pole, AK\",\"description\":\"please don't hurt me\",\"url\":\"https:\\/\\/t.co\\/cHZdP4MpC4\",\"entities\":{\"url\":{\"urls\":[{\"url\":\"https:\\/\\/t.co\\/cHZdP4MpC4\",\"expanded_url\":\"http:\\/\\/google.com\",\"display_url\":\"google.com\",\"indices\":[0,23]}]},\"description\":{\"urls\":[]}},\"protected\":false,\"followers_count\":1,\"friends_count\":10,\"listed_count\":0,\"created_at\":\"Thu Nov 29 11:31:18 +0000 2018\",\"favourites_count\":14,\"utc_offset\":null,\"time_zone\":null,\"geo_enabled\":false,\"verified\":false,\"statuses_count\":46,\"lang\":null,\"contributors_enabled\":false,\"is_translator\":false,\"is_translation_enabled\":false,\"profile_background_color\":\"000000\",\"profile_background_image_url\":\"http:\\/\\/abs.twimg.com\\/images\\/themes\\/theme1\\/bg.png\",\"profile_background_image_url_https\":\"https:\\/\\/abs.twimg.com\\/images\\/themes\\/theme1\\/bg.png\",\"profile_background_tile\":false,\"profile_image_url\":\"http:\\/\\/abs.twimg.com\\/sticky\\/default_profile_images\\/default_profile_normal.png\",\"profile_image_url_https\":\"https:\\/\\/abs.twimg.com\\/sticky\\/default_profile_images\\/default_profile_normal.png\",\"profile_link_color\":\"981CEB\",\"profile_sidebar_border_color\":\"000000\",\"profile_sidebar_fill_color\":\"000000\",\"profile_text_color\":\"000000\",\"profile_use_background_image\":false,\"has_extended_profile\":true,\"default_profile\":false,\"default_profile_image\":true,\"following\":false,\"follow_request_sent\":false,\"notifications\":false,\"translator_type\":\"none\"},\"geo\":null,\"coordinates\":null,\"place\":null,\"contributors\":null,\"is_quote_status\":false,\"retweet_count\":0,\"favorite_count\":0,\"favorited\":false,\"retweeted\":false,\"lang\":\"und\"}''';

const _showResponse =
    '''{\"created_at\":\"Mon Dec 23 21:30:01 +0000 2019\",\"id\":1209224666646274048,\"id_str\":\"1209224666646274048\",\"full_text\":\"\\ud83c\\udf89Dart has added a new feature called Extension Methods. \\u26a1\\n\\nNow you can add functionality to existing libraries. \\ud83d\\udcc1\\n \\nWatch here \\u2192  https:\\/\\/t.co\\/bYcGRLBwbO https:\\/\\/t.co\\/7LvVNVBN4X\",\"truncated\":false,\"display_text_range\":[0,153],\"entities\":{\"hashtags\":[],\"symbols\":[],\"user_mentions\":[],\"urls\":[{\"url\":\"https:\\/\\/t.co\\/bYcGRLBwbO\",\"expanded_url\":\"https:\\/\\/goo.gle\\/399jCKI\",\"display_url\":\"goo.gle\\/399jCKI\",\"indices\":[130,153]}],\"media\":[{\"id\":1209224663794159616,\"id_str\":\"1209224663794159616\",\"indices\":[154,177],\"media_url\":\"http:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"media_url_https\":\"https:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"url\":\"https:\\/\\/t.co\\/7LvVNVBN4X\",\"display_url\":\"pic.twitter.com\\/7LvVNVBN4X\",\"expanded_url\":\"https:\\/\\/twitter.com\\/dart_lang\\/status\\/1209224666646274048\\/photo\\/1\",\"type\":\"photo\",\"sizes\":{\"small\":{\"w\":680,\"h\":383,\"resize\":\"fit\"},\"thumb\":{\"w\":150,\"h\":150,\"resize\":\"crop\"},\"medium\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"},\"large\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"}}}]},\"extended_entities\":{\"media\":[{\"id\":1209224663794159616,\"id_str\":\"1209224663794159616\",\"indices\":[154,177],\"media_url\":\"http:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"media_url_https\":\"https:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"url\":\"https:\\/\\/t.co\\/7LvVNVBN4X\",\"display_url\":\"pic.twitter.com\\/7LvVNVBN4X\",\"expanded_url\":\"https:\\/\\/twitter.com\\/dart_lang\\/status\\/1209224666646274048\\/photo\\/1\",\"type\":\"photo\",\"sizes\":{\"small\":{\"w\":680,\"h\":383,\"resize\":\"fit\"},\"thumb\":{\"w\":150,\"h\":150,\"resize\":\"crop\"},\"medium\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"},\"large\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"}}}]},\"source\":\"\\u003ca href=\\\"https:\\/\\/www.sprinklr.com\\\" rel=\\\"nofollow\\\"\\u003eSprinklr\\u003c\\/a\\u003e\",\"in_reply_to_status_id\":null,\"in_reply_to_status_id_str\":null,\"in_reply_to_user_id\":null,\"in_reply_to_user_id_str\":null,\"in_reply_to_screen_name\":null,\"user\":{\"id\":376585411,\"id_str\":\"376585411\",\"name\":\"Dart Language\",\"screen_name\":\"dart_lang\",\"location\":\"\",\"description\":\"A client-optimized language for fast apps on any platform\",\"url\":\"https:\\/\\/t.co\\/FjOTI9dOPj\",\"entities\":{\"url\":{\"urls\":[{\"url\":\"https:\\/\\/t.co\\/FjOTI9dOPj\",\"expanded_url\":\"http:\\/\\/dart.dev\",\"display_url\":\"dart.dev\",\"indices\":[0,23]}]},\"description\":{\"urls\":[]}},\"protected\":false,\"followers_count\":41122,\"friends_count\":52,\"listed_count\":685,\"created_at\":\"Tue Sep 20 04:21:29 +0000 2011\",\"favourites_count\":245,\"utc_offset\":null,\"time_zone\":null,\"geo_enabled\":true,\"verified\":false,\"statuses_count\":1662,\"lang\":null,\"contributors_enabled\":false,\"is_translator\":false,\"is_translation_enabled\":false,\"profile_background_color\":\"FFFFFF\",\"profile_background_image_url\":\"http:\\/\\/abs.twimg.com\\/images\\/themes\\/theme1\\/bg.png\",\"profile_background_image_url_https\":\"https:\\/\\/abs.twimg.com\\/images\\/themes\\/theme1\\/bg.png\",\"profile_background_tile\":false,\"profile_image_url\":\"http:\\/\\/pbs.twimg.com\\/profile_images\\/993555605078994945\\/Yr-pWI4G_normal.jpg\",\"profile_image_url_https\":\"https:\\/\\/pbs.twimg.com\\/profile_images\\/993555605078994945\\/Yr-pWI4G_normal.jpg\",\"profile_banner_url\":\"https:\\/\\/pbs.twimg.com\\/profile_banners\\/376585411\\/1557177130\",\"profile_link_color\":\"0081C6\",\"profile_sidebar_border_color\":\"FFFFFF\",\"profile_sidebar_fill_color\":\"F2F2F2\",\"profile_text_color\":\"000000\",\"profile_use_background_image\":false,\"has_extended_profile\":false,\"default_profile\":false,\"default_profile_image\":false,\"following\":true,\"follow_request_sent\":false,\"notifications\":false,\"translator_type\":\"none\"},\"geo\":null,\"coordinates\":null,\"place\":null,\"contributors\":null,\"is_quote_status\":false,\"retweet_count\":45,\"favorite_count\":211,\"favorited\":false,\"retweeted\":false,\"possibly_sensitive\":false,\"possibly_sensitive_appealable\":false,\"lang\":\"en\"}''';

const _retweetResponse =
    '''{\"created_at\":\"Wed Jun 03 20:29:13 +0000 2020\",\"id\":1268278588190711814,\"id_str\":\"1268278588190711814\",\"full_text\":\"RT @dart_lang: \\ud83c\\udf89Dart has added a new feature called Extension Methods. \\u26a1\\n\\nNow you can add functionality to existing libraries. \\ud83d\\udcc1\\n \\nWatch he\\u2026\",\"truncated\":false,\"display_text_range\":[0,140],\"entities\":{\"hashtags\":[],\"symbols\":[],\"user_mentions\":[{\"screen_name\":\"dart_lang\",\"name\":\"Dart Language\",\"id\":376585411,\"id_str\":\"376585411\",\"indices\":[3,13]}],\"urls\":[]},\"source\":\"\\u003ca href=\\\"http:\\/\\/robertodoering.com\\\" rel=\\\"nofollow\\\"\\u003eDart Wrapper\\u003c\\/a\\u003e\",\"in_reply_to_status_id\":null,\"in_reply_to_status_id_str\":null,\"in_reply_to_user_id\":null,\"in_reply_to_user_id_str\":null,\"in_reply_to_screen_name\":null,\"user\":{\"id\":1068105113284300800,\"id_str\":\"1068105113284300800\",\"name\":\"Harpy App\",\"screen_name\":\"harpy_app\",\"location\":\"North Pole, AK\",\"description\":\"please don't hurt me\",\"url\":\"https:\\/\\/t.co\\/cHZdP4MpC4\",\"entities\":{\"url\":{\"urls\":[{\"url\":\"https:\\/\\/t.co\\/cHZdP4MpC4\",\"expanded_url\":\"http:\\/\\/google.com\",\"display_url\":\"google.com\",\"indices\":[0,23]}]},\"description\":{\"urls\":[]}},\"protected\":false,\"followers_count\":1,\"friends_count\":10,\"listed_count\":0,\"created_at\":\"Thu Nov 29 11:31:18 +0000 2018\",\"favourites_count\":14,\"utc_offset\":null,\"time_zone\":null,\"geo_enabled\":false,\"verified\":false,\"statuses_count\":46,\"lang\":null,\"contributors_enabled\":false,\"is_translator\":false,\"is_translation_enabled\":false,\"profile_background_color\":\"000000\",\"profile_background_image_url\":\"http:\\/\\/abs.twimg.com\\/images\\/themes\\/theme1\\/bg.png\",\"profile_background_image_url_https\":\"https:\\/\\/abs.twimg.com\\/images\\/themes\\/theme1\\/bg.png\",\"profile_background_tile\":false,\"profile_image_url\":\"http:\\/\\/abs.twimg.com\\/sticky\\/default_profile_images\\/default_profile_normal.png\",\"profile_image_url_https\":\"https:\\/\\/abs.twimg.com\\/sticky\\/default_profile_images\\/default_profile_normal.png\",\"profile_link_color\":\"981CEB\",\"profile_sidebar_border_color\":\"000000\",\"profile_sidebar_fill_color\":\"000000\",\"profile_text_color\":\"000000\",\"profile_use_background_image\":false,\"has_extended_profile\":true,\"default_profile\":false,\"default_profile_image\":true,\"following\":false,\"follow_request_sent\":false,\"notifications\":false,\"translator_type\":\"none\"},\"geo\":null,\"coordinates\":null,\"place\":null,\"contributors\":null,\"retweeted_status\":{\"created_at\":\"Mon Dec 23 21:30:01 +0000 2019\",\"id\":1209224666646274048,\"id_str\":\"1209224666646274048\",\"full_text\":\"\\ud83c\\udf89Dart has added a new feature called Extension Methods. \\u26a1\\n\\nNow you can add functionality to existing libraries. \\ud83d\\udcc1\\n \\nWatch here \\u2192  https:\\/\\/t.co\\/bYcGRLBwbO https:\\/\\/t.co\\/7LvVNVBN4X\",\"truncated\":false,\"display_text_range\":[0,153],\"entities\":{\"hashtags\":[],\"symbols\":[],\"user_mentions\":[],\"urls\":[{\"url\":\"https:\\/\\/t.co\\/bYcGRLBwbO\",\"expanded_url\":\"https:\\/\\/goo.gle\\/399jCKI\",\"display_url\":\"goo.gle\\/399jCKI\",\"indices\":[130,153]}],\"media\":[{\"id\":1209224663794159616,\"id_str\":\"1209224663794159616\",\"indices\":[154,177],\"media_url\":\"http:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"media_url_https\":\"https:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"url\":\"https:\\/\\/t.co\\/7LvVNVBN4X\",\"display_url\":\"pic.twitter.com\\/7LvVNVBN4X\",\"expanded_url\":\"https:\\/\\/twitter.com\\/dart_lang\\/status\\/1209224666646274048\\/photo\\/1\",\"type\":\"photo\",\"sizes\":{\"small\":{\"w\":680,\"h\":383,\"resize\":\"fit\"},\"thumb\":{\"w\":150,\"h\":150,\"resize\":\"crop\"},\"medium\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"},\"large\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"}}}]},\"extended_entities\":{\"media\":[{\"id\":1209224663794159616,\"id_str\":\"1209224663794159616\",\"indices\":[154,177],\"media_url\":\"http:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"media_url_https\":\"https:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"url\":\"https:\\/\\/t.co\\/7LvVNVBN4X\",\"display_url\":\"pic.twitter.com\\/7LvVNVBN4X\",\"expanded_url\":\"https:\\/\\/twitter.com\\/dart_lang\\/status\\/1209224666646274048\\/photo\\/1\",\"type\":\"photo\",\"sizes\":{\"small\":{\"w\":680,\"h\":383,\"resize\":\"fit\"},\"thumb\":{\"w\":150,\"h\":150,\"resize\":\"crop\"},\"medium\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"},\"large\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"}}}]},\"source\":\"\\u003ca href=\\\"https:\\/\\/www.sprinklr.com\\\" rel=\\\"nofollow\\\"\\u003eSprinklr\\u003c\\/a\\u003e\",\"in_reply_to_status_id\":null,\"in_reply_to_status_id_str\":null,\"in_reply_to_user_id\":null,\"in_reply_to_user_id_str\":null,\"in_reply_to_screen_name\":null,\"user\":{\"id\":376585411,\"id_str\":\"376585411\",\"name\":\"Dart Language\",\"screen_name\":\"dart_lang\",\"location\":\"\",\"description\":\"A client-optimized language for fast apps on any platform\",\"url\":\"https:\\/\\/t.co\\/FjOTI9dOPj\",\"entities\":{\"url\":{\"urls\":[{\"url\":\"https:\\/\\/t.co\\/FjOTI9dOPj\",\"expanded_url\":\"http:\\/\\/dart.dev\",\"display_url\":\"dart.dev\",\"indices\":[0,23]}]},\"description\":{\"urls\":[]}},\"protected\":false,\"followers_count\":41122,\"friends_count\":52,\"listed_count\":685,\"created_at\":\"Tue Sep 20 04:21:29 +0000 2011\",\"favourites_count\":246,\"utc_offset\":null,\"time_zone\":null,\"geo_enabled\":true,\"verified\":false,\"statuses_count\":1662,\"lang\":null,\"contributors_enabled\":false,\"is_translator\":false,\"is_translation_enabled\":false,\"profile_background_color\":\"FFFFFF\",\"profile_background_image_url\":\"http:\\/\\/abs.twimg.com\\/images\\/themes\\/theme1\\/bg.png\",\"profile_background_image_url_https\":\"https:\\/\\/abs.twimg.com\\/images\\/themes\\/theme1\\/bg.png\",\"profile_background_tile\":false,\"profile_image_url\":\"http:\\/\\/pbs.twimg.com\\/profile_images\\/993555605078994945\\/Yr-pWI4G_normal.jpg\",\"profile_image_url_https\":\"https:\\/\\/pbs.twimg.com\\/profile_images\\/993555605078994945\\/Yr-pWI4G_normal.jpg\",\"profile_banner_url\":\"https:\\/\\/pbs.twimg.com\\/profile_banners\\/376585411\\/1557177130\",\"profile_link_color\":\"0081C6\",\"profile_sidebar_border_color\":\"FFFFFF\",\"profile_sidebar_fill_color\":\"F2F2F2\",\"profile_text_color\":\"000000\",\"profile_use_background_image\":false,\"has_extended_profile\":false,\"default_profile\":false,\"default_profile_image\":false,\"following\":true,\"follow_request_sent\":false,\"notifications\":false,\"translator_type\":\"none\"},\"geo\":null,\"coordinates\":null,\"place\":null,\"contributors\":null,\"is_quote_status\":false,\"retweet_count\":46,\"favorite_count\":211,\"favorited\":false,\"retweeted\":true,\"possibly_sensitive\":false,\"lang\":\"en\"},\"is_quote_status\":false,\"retweet_count\":46,\"favorite_count\":0,\"favorited\":false,\"retweeted\":true,\"lang\":\"en\"}''';

const _unretweetResponse =
    '''{\"created_at\":\"Mon Dec 23 21:30:01 +0000 2019\",\"id\":1209224666646274048,\"id_str\":\"1209224666646274048\",\"full_text\":\"\\ud83c\\udf89Dart has added a new feature called Extension Methods. \\u26a1\\n\\nNow you can add functionality to existing libraries. \\ud83d\\udcc1\\n \\nWatch here \\u2192  https:\\/\\/t.co\\/bYcGRLBwbO https:\\/\\/t.co\\/7LvVNVBN4X\",\"truncated\":false,\"display_text_range\":[0,153],\"entities\":{\"hashtags\":[],\"symbols\":[],\"user_mentions\":[],\"urls\":[{\"url\":\"https:\\/\\/t.co\\/bYcGRLBwbO\",\"expanded_url\":\"https:\\/\\/goo.gle\\/399jCKI\",\"display_url\":\"goo.gle\\/399jCKI\",\"indices\":[130,153]}],\"media\":[{\"id\":1209224663794159616,\"id_str\":\"1209224663794159616\",\"indices\":[154,177],\"media_url\":\"http:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"media_url_https\":\"https:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"url\":\"https:\\/\\/t.co\\/7LvVNVBN4X\",\"display_url\":\"pic.twitter.com\\/7LvVNVBN4X\",\"expanded_url\":\"https:\\/\\/twitter.com\\/dart_lang\\/status\\/1209224666646274048\\/photo\\/1\",\"type\":\"photo\",\"sizes\":{\"small\":{\"w\":680,\"h\":383,\"resize\":\"fit\"},\"thumb\":{\"w\":150,\"h\":150,\"resize\":\"crop\"},\"medium\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"},\"large\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"}}}]},\"extended_entities\":{\"media\":[{\"id\":1209224663794159616,\"id_str\":\"1209224663794159616\",\"indices\":[154,177],\"media_url\":\"http:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"media_url_https\":\"https:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"url\":\"https:\\/\\/t.co\\/7LvVNVBN4X\",\"display_url\":\"pic.twitter.com\\/7LvVNVBN4X\",\"expanded_url\":\"https:\\/\\/twitter.com\\/dart_lang\\/status\\/1209224666646274048\\/photo\\/1\",\"type\":\"photo\",\"sizes\":{\"small\":{\"w\":680,\"h\":383,\"resize\":\"fit\"},\"thumb\":{\"w\":150,\"h\":150,\"resize\":\"crop\"},\"medium\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"},\"large\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"}}}]},\"source\":\"\\u003ca href=\\\"https:\\/\\/www.sprinklr.com\\\" rel=\\\"nofollow\\\"\\u003eSprinklr\\u003c\\/a\\u003e\",\"in_reply_to_status_id\":null,\"in_reply_to_status_id_str\":null,\"in_reply_to_user_id\":null,\"in_reply_to_user_id_str\":null,\"in_reply_to_screen_name\":null,\"user\":{\"id\":376585411,\"id_str\":\"376585411\",\"name\":\"Dart Language\",\"screen_name\":\"dart_lang\",\"location\":\"\",\"description\":\"A client-optimized language for fast apps on any platform\",\"url\":\"https:\\/\\/t.co\\/FjOTI9dOPj\",\"entities\":{\"url\":{\"urls\":[{\"url\":\"https:\\/\\/t.co\\/FjOTI9dOPj\",\"expanded_url\":\"http:\\/\\/dart.dev\",\"display_url\":\"dart.dev\",\"indices\":[0,23]}]},\"description\":{\"urls\":[]}},\"protected\":false,\"followers_count\":41123,\"friends_count\":52,\"listed_count\":685,\"created_at\":\"Tue Sep 20 04:21:29 +0000 2011\",\"favourites_count\":246,\"utc_offset\":null,\"time_zone\":null,\"geo_enabled\":true,\"verified\":false,\"statuses_count\":1662,\"lang\":null,\"contributors_enabled\":false,\"is_translator\":false,\"is_translation_enabled\":false,\"profile_background_color\":\"FFFFFF\",\"profile_background_image_url\":\"http:\\/\\/abs.twimg.com\\/images\\/themes\\/theme1\\/bg.png\",\"profile_background_image_url_https\":\"https:\\/\\/abs.twimg.com\\/images\\/themes\\/theme1\\/bg.png\",\"profile_background_tile\":false,\"profile_image_url\":\"http:\\/\\/pbs.twimg.com\\/profile_images\\/993555605078994945\\/Yr-pWI4G_normal.jpg\",\"profile_image_url_https\":\"https:\\/\\/pbs.twimg.com\\/profile_images\\/993555605078994945\\/Yr-pWI4G_normal.jpg\",\"profile_banner_url\":\"https:\\/\\/pbs.twimg.com\\/profile_banners\\/376585411\\/1557177130\",\"profile_link_color\":\"0081C6\",\"profile_sidebar_border_color\":\"FFFFFF\",\"profile_sidebar_fill_color\":\"F2F2F2\",\"profile_text_color\":\"000000\",\"profile_use_background_image\":false,\"has_extended_profile\":false,\"default_profile\":false,\"default_profile_image\":false,\"following\":true,\"follow_request_sent\":false,\"notifications\":false,\"translator_type\":\"none\"},\"geo\":null,\"coordinates\":null,\"place\":null,\"contributors\":null,\"is_quote_status\":false,\"retweet_count\":46,\"favorite_count\":211,\"favorited\":false,\"retweeted\":true,\"possibly_sensitive\":false,\"lang\":\"en\"}''';

const _retweetsResponse =
    '''[{\"created_at\":\"Sat Apr 04 13:57:59 +0000 2020\",\"id\":1246436859804344320,\"id_str\":\"1246436859804344320\",\"full_text\":\"RT @dart_lang: \\ud83c\\udf89Dart has added a new feature called Extension Methods. \\u26a1\\n\\nNow you can add functionality to existing libraries. \\ud83d\\udcc1\\n \\nWatch he\\u2026\",\"truncated\":false,\"display_text_range\":[0,140],\"entities\":{\"hashtags\":[],\"symbols\":[],\"user_mentions\":[{\"screen_name\":\"dart_lang\",\"name\":\"Dart Language\",\"id\":376585411,\"id_str\":\"376585411\",\"indices\":[3,13]}],\"urls\":[]},\"source\":\"\\u003ca href=\\\"https:\\/\\/mobile.twitter.com\\\" rel=\\\"nofollow\\\"\\u003eTwitter Web App\\u003c\\/a\\u003e\",\"in_reply_to_status_id\":null,\"in_reply_to_status_id_str\":null,\"in_reply_to_user_id\":null,\"in_reply_to_user_id_str\":null,\"in_reply_to_screen_name\":null,\"user\":{\"id\":852405431012077568,\"id_str\":\"852405431012077568\"},\"geo\":null,\"coordinates\":null,\"place\":null,\"contributors\":null,\"retweeted_status\":{\"created_at\":\"Mon Dec 23 21:30:01 +0000 2019\",\"id\":1209224666646274048,\"id_str\":\"1209224666646274048\",\"full_text\":\"\\ud83c\\udf89Dart has added a new feature called Extension Methods. \\u26a1\\n\\nNow you can add functionality to existing libraries. \\ud83d\\udcc1\\n \\nWatch here \\u2192  https:\\/\\/t.co\\/bYcGRLBwbO https:\\/\\/t.co\\/7LvVNVBN4X\",\"truncated\":false,\"display_text_range\":[0,153],\"entities\":{\"hashtags\":[],\"symbols\":[],\"user_mentions\":[],\"urls\":[{\"url\":\"https:\\/\\/t.co\\/bYcGRLBwbO\",\"expanded_url\":\"https:\\/\\/goo.gle\\/399jCKI\",\"display_url\":\"goo.gle\\/399jCKI\",\"indices\":[130,153]}],\"media\":[{\"id\":1209224663794159616,\"id_str\":\"1209224663794159616\",\"indices\":[154,177],\"media_url\":\"http:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"media_url_https\":\"https:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"url\":\"https:\\/\\/t.co\\/7LvVNVBN4X\",\"display_url\":\"pic.twitter.com\\/7LvVNVBN4X\",\"expanded_url\":\"https:\\/\\/twitter.com\\/dart_lang\\/status\\/1209224666646274048\\/photo\\/1\",\"type\":\"photo\",\"sizes\":{\"small\":{\"w\":680,\"h\":383,\"resize\":\"fit\"},\"thumb\":{\"w\":150,\"h\":150,\"resize\":\"crop\"},\"medium\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"},\"large\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"}}}]},\"extended_entities\":{\"media\":[{\"id\":1209224663794159616,\"id_str\":\"1209224663794159616\",\"indices\":[154,177],\"media_url\":\"http:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"media_url_https\":\"https:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"url\":\"https:\\/\\/t.co\\/7LvVNVBN4X\",\"display_url\":\"pic.twitter.com\\/7LvVNVBN4X\",\"expanded_url\":\"https:\\/\\/twitter.com\\/dart_lang\\/status\\/1209224666646274048\\/photo\\/1\",\"type\":\"photo\",\"sizes\":{\"small\":{\"w\":680,\"h\":383,\"resize\":\"fit\"},\"thumb\":{\"w\":150,\"h\":150,\"resize\":\"crop\"},\"medium\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"},\"large\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"}}}]},\"source\":\"\\u003ca href=\\\"https:\\/\\/www.sprinklr.com\\\" rel=\\\"nofollow\\\"\\u003eSprinklr\\u003c\\/a\\u003e\",\"in_reply_to_status_id\":null,\"in_reply_to_status_id_str\":null,\"in_reply_to_user_id\":null,\"in_reply_to_user_id_str\":null,\"in_reply_to_screen_name\":null,\"user\":{\"id\":376585411,\"id_str\":\"376585411\"},\"geo\":null,\"coordinates\":null,\"place\":null,\"contributors\":null,\"is_quote_status\":false,\"retweet_count\":45,\"favorite_count\":211,\"favorited\":false,\"retweeted\":false,\"possibly_sensitive\":false,\"lang\":\"en\"},\"is_quote_status\":false,\"retweet_count\":45,\"favorite_count\":0,\"favorited\":false,\"retweeted\":false,\"lang\":\"en\"},{\"created_at\":\"Mon Dec 30 19:51:39 +0000 2019\",\"id\":1211736625916432384,\"id_str\":\"1211736625916432384\",\"full_text\":\"RT @dart_lang: \\ud83c\\udf89Dart has added a new feature called Extension Methods. \\u26a1\\n\\nNow you can add functionality to existing libraries. \\ud83d\\udcc1\\n \\nWatch he\\u2026\",\"truncated\":false,\"display_text_range\":[0,140],\"entities\":{\"hashtags\":[],\"symbols\":[],\"user_mentions\":[{\"screen_name\":\"dart_lang\",\"name\":\"Dart Language\",\"id\":376585411,\"id_str\":\"376585411\",\"indices\":[3,13]}],\"urls\":[]},\"source\":\"\\u003ca href=\\\"http:\\/\\/twitter.com\\/download\\/android\\\" rel=\\\"nofollow\\\"\\u003eTwitter for Android\\u003c\\/a\\u003e\",\"in_reply_to_status_id\":null,\"in_reply_to_status_id_str\":null,\"in_reply_to_user_id\":null,\"in_reply_to_user_id_str\":null,\"in_reply_to_screen_name\":null,\"user\":{\"id\":117602970,\"id_str\":\"117602970\"},\"geo\":null,\"coordinates\":null,\"place\":null,\"contributors\":null,\"retweeted_status\":{\"created_at\":\"Mon Dec 23 21:30:01 +0000 2019\",\"id\":1209224666646274048,\"id_str\":\"1209224666646274048\",\"full_text\":\"\\ud83c\\udf89Dart has added a new feature called Extension Methods. \\u26a1\\n\\nNow you can add functionality to existing libraries. \\ud83d\\udcc1\\n \\nWatch here \\u2192  https:\\/\\/t.co\\/bYcGRLBwbO https:\\/\\/t.co\\/7LvVNVBN4X\",\"truncated\":false,\"display_text_range\":[0,153],\"entities\":{\"hashtags\":[],\"symbols\":[],\"user_mentions\":[],\"urls\":[{\"url\":\"https:\\/\\/t.co\\/bYcGRLBwbO\",\"expanded_url\":\"https:\\/\\/goo.gle\\/399jCKI\",\"display_url\":\"goo.gle\\/399jCKI\",\"indices\":[130,153]}],\"media\":[{\"id\":1209224663794159616,\"id_str\":\"1209224663794159616\",\"indices\":[154,177],\"media_url\":\"http:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"media_url_https\":\"https:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"url\":\"https:\\/\\/t.co\\/7LvVNVBN4X\",\"display_url\":\"pic.twitter.com\\/7LvVNVBN4X\",\"expanded_url\":\"https:\\/\\/twitter.com\\/dart_lang\\/status\\/1209224666646274048\\/photo\\/1\",\"type\":\"photo\",\"sizes\":{\"small\":{\"w\":680,\"h\":383,\"resize\":\"fit\"},\"thumb\":{\"w\":150,\"h\":150,\"resize\":\"crop\"},\"medium\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"},\"large\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"}}}]},\"extended_entities\":{\"media\":[{\"id\":1209224663794159616,\"id_str\":\"1209224663794159616\",\"indices\":[154,177],\"media_url\":\"http:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"media_url_https\":\"https:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"url\":\"https:\\/\\/t.co\\/7LvVNVBN4X\",\"display_url\":\"pic.twitter.com\\/7LvVNVBN4X\",\"expanded_url\":\"https:\\/\\/twitter.com\\/dart_lang\\/status\\/1209224666646274048\\/photo\\/1\",\"type\":\"photo\",\"sizes\":{\"small\":{\"w\":680,\"h\":383,\"resize\":\"fit\"},\"thumb\":{\"w\":150,\"h\":150,\"resize\":\"crop\"},\"medium\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"},\"large\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"}}}]},\"source\":\"\\u003ca href=\\\"https:\\/\\/www.sprinklr.com\\\" rel=\\\"nofollow\\\"\\u003eSprinklr\\u003c\\/a\\u003e\",\"in_reply_to_status_id\":null,\"in_reply_to_status_id_str\":null,\"in_reply_to_user_id\":null,\"in_reply_to_user_id_str\":null,\"in_reply_to_screen_name\":null,\"user\":{\"id\":376585411,\"id_str\":\"376585411\"},\"geo\":null,\"coordinates\":null,\"place\":null,\"contributors\":null,\"is_quote_status\":false,\"retweet_count\":45,\"favorite_count\":211,\"favorited\":false,\"retweeted\":false,\"possibly_sensitive\":false,\"lang\":\"en\"},\"is_quote_status\":false,\"retweet_count\":45,\"favorite_count\":0,\"favorited\":false,\"retweeted\":false,\"lang\":\"en\"},{\"created_at\":\"Mon Dec 30 05:25:27 +0000 2019\",\"id\":1211518639070801920,\"id_str\":\"1211518639070801920\",\"full_text\":\"RT @dart_lang: \\ud83c\\udf89Dart has added a new feature called Extension Methods. \\u26a1\\n\\nNow you can add functionality to existing libraries. \\ud83d\\udcc1\\n \\nWatch he\\u2026\",\"truncated\":false,\"display_text_range\":[0,140],\"entities\":{\"hashtags\":[],\"symbols\":[],\"user_mentions\":[{\"screen_name\":\"dart_lang\",\"name\":\"Dart Language\",\"id\":376585411,\"id_str\":\"376585411\",\"indices\":[3,13]}],\"urls\":[]},\"source\":\"\\u003ca href=\\\"https:\\/\\/mobile.twitter.com\\\" rel=\\\"nofollow\\\"\\u003eTwitter Web App\\u003c\\/a\\u003e\",\"in_reply_to_status_id\":null,\"in_reply_to_status_id_str\":null,\"in_reply_to_user_id\":null,\"in_reply_to_user_id_str\":null,\"in_reply_to_screen_name\":null,\"user\":{\"id\":1113914554080055296,\"id_str\":\"1113914554080055296\"},\"geo\":null,\"coordinates\":null,\"place\":null,\"contributors\":null,\"retweeted_status\":{\"created_at\":\"Mon Dec 23 21:30:01 +0000 2019\",\"id\":1209224666646274048,\"id_str\":\"1209224666646274048\",\"full_text\":\"\\ud83c\\udf89Dart has added a new feature called Extension Methods. \\u26a1\\n\\nNow you can add functionality to existing libraries. \\ud83d\\udcc1\\n \\nWatch here \\u2192  https:\\/\\/t.co\\/bYcGRLBwbO https:\\/\\/t.co\\/7LvVNVBN4X\",\"truncated\":false,\"display_text_range\":[0,153],\"entities\":{\"hashtags\":[],\"symbols\":[],\"user_mentions\":[],\"urls\":[{\"url\":\"https:\\/\\/t.co\\/bYcGRLBwbO\",\"expanded_url\":\"https:\\/\\/goo.gle\\/399jCKI\",\"display_url\":\"goo.gle\\/399jCKI\",\"indices\":[130,153]}],\"media\":[{\"id\":1209224663794159616,\"id_str\":\"1209224663794159616\",\"indices\":[154,177],\"media_url\":\"http:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"media_url_https\":\"https:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"url\":\"https:\\/\\/t.co\\/7LvVNVBN4X\",\"display_url\":\"pic.twitter.com\\/7LvVNVBN4X\",\"expanded_url\":\"https:\\/\\/twitter.com\\/dart_lang\\/status\\/1209224666646274048\\/photo\\/1\",\"type\":\"photo\",\"sizes\":{\"small\":{\"w\":680,\"h\":383,\"resize\":\"fit\"},\"thumb\":{\"w\":150,\"h\":150,\"resize\":\"crop\"},\"medium\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"},\"large\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"}}}]},\"extended_entities\":{\"media\":[{\"id\":1209224663794159616,\"id_str\":\"1209224663794159616\",\"indices\":[154,177],\"media_url\":\"http:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"media_url_https\":\"https:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"url\":\"https:\\/\\/t.co\\/7LvVNVBN4X\",\"display_url\":\"pic.twitter.com\\/7LvVNVBN4X\",\"expanded_url\":\"https:\\/\\/twitter.com\\/dart_lang\\/status\\/1209224666646274048\\/photo\\/1\",\"type\":\"photo\",\"sizes\":{\"small\":{\"w\":680,\"h\":383,\"resize\":\"fit\"},\"thumb\":{\"w\":150,\"h\":150,\"resize\":\"crop\"},\"medium\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"},\"large\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"}}}]},\"source\":\"\\u003ca href=\\\"https:\\/\\/www.sprinklr.com\\\" rel=\\\"nofollow\\\"\\u003eSprinklr\\u003c\\/a\\u003e\",\"in_reply_to_status_id\":null,\"in_reply_to_status_id_str\":null,\"in_reply_to_user_id\":null,\"in_reply_to_user_id_str\":null,\"in_reply_to_screen_name\":null,\"user\":{\"id\":376585411,\"id_str\":\"376585411\"},\"geo\":null,\"coordinates\":null,\"place\":null,\"contributors\":null,\"is_quote_status\":false,\"retweet_count\":45,\"favorite_count\":211,\"favorited\":false,\"retweeted\":false,\"possibly_sensitive\":false,\"lang\":\"en\"},\"is_quote_status\":false,\"retweet_count\":45,\"favorite_count\":0,\"favorited\":false,\"retweeted\":false,\"lang\":\"en\"},{\"created_at\":\"Fri Dec 27 14:34:34 +0000 2019\",\"id\":1210569668089352197,\"id_str\":\"1210569668089352197\",\"full_text\":\"RT @dart_lang: \\ud83c\\udf89Dart has added a new feature called Extension Methods. \\u26a1\\n\\nNow you can add functionality to existing libraries. \\ud83d\\udcc1\\n \\nWatch he\\u2026\",\"truncated\":false,\"display_text_range\":[0,140],\"entities\":{\"hashtags\":[],\"symbols\":[],\"user_mentions\":[{\"screen_name\":\"dart_lang\",\"name\":\"Dart Language\",\"id\":376585411,\"id_str\":\"376585411\",\"indices\":[3,13]}],\"urls\":[]},\"source\":\"\\u003ca href=\\\"http:\\/\\/twitter.com\\/download\\/iphone\\\" rel=\\\"nofollow\\\"\\u003eTwitter for iPhone\\u003c\\/a\\u003e\",\"in_reply_to_status_id\":null,\"in_reply_to_status_id_str\":null,\"in_reply_to_user_id\":null,\"in_reply_to_user_id_str\":null,\"in_reply_to_screen_name\":null,\"user\":{\"id\":2420028997,\"id_str\":\"2420028997\"},\"geo\":null,\"coordinates\":null,\"place\":null,\"contributors\":null,\"retweeted_status\":{\"created_at\":\"Mon Dec 23 21:30:01 +0000 2019\",\"id\":1209224666646274048,\"id_str\":\"1209224666646274048\",\"full_text\":\"\\ud83c\\udf89Dart has added a new feature called Extension Methods. \\u26a1\\n\\nNow you can add functionality to existing libraries. \\ud83d\\udcc1\\n \\nWatch here \\u2192  https:\\/\\/t.co\\/bYcGRLBwbO https:\\/\\/t.co\\/7LvVNVBN4X\",\"truncated\":false,\"display_text_range\":[0,153],\"entities\":{\"hashtags\":[],\"symbols\":[],\"user_mentions\":[],\"urls\":[{\"url\":\"https:\\/\\/t.co\\/bYcGRLBwbO\",\"expanded_url\":\"https:\\/\\/goo.gle\\/399jCKI\",\"display_url\":\"goo.gle\\/399jCKI\",\"indices\":[130,153]}],\"media\":[{\"id\":1209224663794159616,\"id_str\":\"1209224663794159616\",\"indices\":[154,177],\"media_url\":\"http:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"media_url_https\":\"https:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"url\":\"https:\\/\\/t.co\\/7LvVNVBN4X\",\"display_url\":\"pic.twitter.com\\/7LvVNVBN4X\",\"expanded_url\":\"https:\\/\\/twitter.com\\/dart_lang\\/status\\/1209224666646274048\\/photo\\/1\",\"type\":\"photo\",\"sizes\":{\"small\":{\"w\":680,\"h\":383,\"resize\":\"fit\"},\"thumb\":{\"w\":150,\"h\":150,\"resize\":\"crop\"},\"medium\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"},\"large\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"}}}]},\"extended_entities\":{\"media\":[{\"id\":1209224663794159616,\"id_str\":\"1209224663794159616\",\"indices\":[154,177],\"media_url\":\"http:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"media_url_https\":\"https:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"url\":\"https:\\/\\/t.co\\/7LvVNVBN4X\",\"display_url\":\"pic.twitter.com\\/7LvVNVBN4X\",\"expanded_url\":\"https:\\/\\/twitter.com\\/dart_lang\\/status\\/1209224666646274048\\/photo\\/1\",\"type\":\"photo\",\"sizes\":{\"small\":{\"w\":680,\"h\":383,\"resize\":\"fit\"},\"thumb\":{\"w\":150,\"h\":150,\"resize\":\"crop\"},\"medium\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"},\"large\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"}}}]},\"source\":\"\\u003ca href=\\\"https:\\/\\/www.sprinklr.com\\\" rel=\\\"nofollow\\\"\\u003eSprinklr\\u003c\\/a\\u003e\",\"in_reply_to_status_id\":null,\"in_reply_to_status_id_str\":null,\"in_reply_to_user_id\":null,\"in_reply_to_user_id_str\":null,\"in_reply_to_screen_name\":null,\"user\":{\"id\":376585411,\"id_str\":\"376585411\"},\"geo\":null,\"coordinates\":null,\"place\":null,\"contributors\":null,\"is_quote_status\":false,\"retweet_count\":45,\"favorite_count\":211,\"favorited\":false,\"retweeted\":false,\"possibly_sensitive\":false,\"lang\":\"en\"},\"is_quote_status\":false,\"retweet_count\":45,\"favorite_count\":0,\"favorited\":false,\"retweeted\":false,\"lang\":\"en\"},{\"created_at\":\"Thu Dec 26 07:54:56 +0000 2019\",\"id\":1210106708929982465,\"id_str\":\"1210106708929982465\",\"full_text\":\"RT @dart_lang: \\ud83c\\udf89Dart has added a new feature called Extension Methods. \\u26a1\\n\\nNow you can add functionality to existing libraries. \\ud83d\\udcc1\\n \\nWatch he\\u2026\",\"truncated\":false,\"display_text_range\":[0,140],\"entities\":{\"hashtags\":[],\"symbols\":[],\"user_mentions\":[{\"screen_name\":\"dart_lang\",\"name\":\"Dart Language\",\"id\":376585411,\"id_str\":\"376585411\",\"indices\":[3,13]}],\"urls\":[]},\"source\":\"\\u003ca href=\\\"http:\\/\\/twitter.com\\/download\\/iphone\\\" rel=\\\"nofollow\\\"\\u003eTwitter for iPhone\\u003c\\/a\\u003e\",\"in_reply_to_status_id\":null,\"in_reply_to_status_id_str\":null,\"in_reply_to_user_id\":null,\"in_reply_to_user_id_str\":null,\"in_reply_to_screen_name\":null,\"user\":{\"id\":151514122,\"id_str\":\"151514122\"},\"geo\":null,\"coordinates\":null,\"place\":null,\"contributors\":null,\"retweeted_status\":{\"created_at\":\"Mon Dec 23 21:30:01 +0000 2019\",\"id\":1209224666646274048,\"id_str\":\"1209224666646274048\",\"full_text\":\"\\ud83c\\udf89Dart has added a new feature called Extension Methods. \\u26a1\\n\\nNow you can add functionality to existing libraries. \\ud83d\\udcc1\\n \\nWatch here \\u2192  https:\\/\\/t.co\\/bYcGRLBwbO https:\\/\\/t.co\\/7LvVNVBN4X\",\"truncated\":false,\"display_text_range\":[0,153],\"entities\":{\"hashtags\":[],\"symbols\":[],\"user_mentions\":[],\"urls\":[{\"url\":\"https:\\/\\/t.co\\/bYcGRLBwbO\",\"expanded_url\":\"https:\\/\\/goo.gle\\/399jCKI\",\"display_url\":\"goo.gle\\/399jCKI\",\"indices\":[130,153]}],\"media\":[{\"id\":1209224663794159616,\"id_str\":\"1209224663794159616\",\"indices\":[154,177],\"media_url\":\"http:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"media_url_https\":\"https:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"url\":\"https:\\/\\/t.co\\/7LvVNVBN4X\",\"display_url\":\"pic.twitter.com\\/7LvVNVBN4X\",\"expanded_url\":\"https:\\/\\/twitter.com\\/dart_lang\\/status\\/1209224666646274048\\/photo\\/1\",\"type\":\"photo\",\"sizes\":{\"small\":{\"w\":680,\"h\":383,\"resize\":\"fit\"},\"thumb\":{\"w\":150,\"h\":150,\"resize\":\"crop\"},\"medium\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"},\"large\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"}}}]},\"extended_entities\":{\"media\":[{\"id\":1209224663794159616,\"id_str\":\"1209224663794159616\",\"indices\":[154,177],\"media_url\":\"http:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"media_url_https\":\"https:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"url\":\"https:\\/\\/t.co\\/7LvVNVBN4X\",\"display_url\":\"pic.twitter.com\\/7LvVNVBN4X\",\"expanded_url\":\"https:\\/\\/twitter.com\\/dart_lang\\/status\\/1209224666646274048\\/photo\\/1\",\"type\":\"photo\",\"sizes\":{\"small\":{\"w\":680,\"h\":383,\"resize\":\"fit\"},\"thumb\":{\"w\":150,\"h\":150,\"resize\":\"crop\"},\"medium\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"},\"large\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"}}}]},\"source\":\"\\u003ca href=\\\"https:\\/\\/www.sprinklr.com\\\" rel=\\\"nofollow\\\"\\u003eSprinklr\\u003c\\/a\\u003e\",\"in_reply_to_status_id\":null,\"in_reply_to_status_id_str\":null,\"in_reply_to_user_id\":null,\"in_reply_to_user_id_str\":null,\"in_reply_to_screen_name\":null,\"user\":{\"id\":376585411,\"id_str\":\"376585411\"},\"geo\":null,\"coordinates\":null,\"place\":null,\"contributors\":null,\"is_quote_status\":false,\"retweet_count\":45,\"favorite_count\":211,\"favorited\":false,\"retweeted\":false,\"possibly_sensitive\":false,\"lang\":\"en\"},\"is_quote_status\":false,\"retweet_count\":45,\"favorite_count\":0,\"favorited\":false,\"retweeted\":false,\"lang\":\"en\"},{\"created_at\":\"Thu Dec 26 07:39:17 +0000 2019\",\"id\":1210102767509000192,\"id_str\":\"1210102767509000192\",\"full_text\":\"RT @dart_lang: \\ud83c\\udf89Dart has added a new feature called Extension Methods. \\u26a1\\n\\nNow you can add functionality to existing libraries. \\ud83d\\udcc1\\n \\nWatch he\\u2026\",\"truncated\":false,\"display_text_range\":[0,140],\"entities\":{\"hashtags\":[],\"symbols\":[],\"user_mentions\":[{\"screen_name\":\"dart_lang\",\"name\":\"Dart Language\",\"id\":376585411,\"id_str\":\"376585411\",\"indices\":[3,13]}],\"urls\":[]},\"source\":\"\\u003ca href=\\\"http:\\/\\/twitter.com\\/download\\/android\\\" rel=\\\"nofollow\\\"\\u003eTwitter for Android\\u003c\\/a\\u003e\",\"in_reply_to_status_id\":null,\"in_reply_to_status_id_str\":null,\"in_reply_to_user_id\":null,\"in_reply_to_user_id_str\":null,\"in_reply_to_screen_name\":null,\"user\":{\"id\":169816327,\"id_str\":\"169816327\"},\"geo\":null,\"coordinates\":null,\"place\":null,\"contributors\":null,\"retweeted_status\":{\"created_at\":\"Mon Dec 23 21:30:01 +0000 2019\",\"id\":1209224666646274048,\"id_str\":\"1209224666646274048\",\"full_text\":\"\\ud83c\\udf89Dart has added a new feature called Extension Methods. \\u26a1\\n\\nNow you can add functionality to existing libraries. \\ud83d\\udcc1\\n \\nWatch here \\u2192  https:\\/\\/t.co\\/bYcGRLBwbO https:\\/\\/t.co\\/7LvVNVBN4X\",\"truncated\":false,\"display_text_range\":[0,153],\"entities\":{\"hashtags\":[],\"symbols\":[],\"user_mentions\":[],\"urls\":[{\"url\":\"https:\\/\\/t.co\\/bYcGRLBwbO\",\"expanded_url\":\"https:\\/\\/goo.gle\\/399jCKI\",\"display_url\":\"goo.gle\\/399jCKI\",\"indices\":[130,153]}],\"media\":[{\"id\":1209224663794159616,\"id_str\":\"1209224663794159616\",\"indices\":[154,177],\"media_url\":\"http:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"media_url_https\":\"https:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"url\":\"https:\\/\\/t.co\\/7LvVNVBN4X\",\"display_url\":\"pic.twitter.com\\/7LvVNVBN4X\",\"expanded_url\":\"https:\\/\\/twitter.com\\/dart_lang\\/status\\/1209224666646274048\\/photo\\/1\",\"type\":\"photo\",\"sizes\":{\"small\":{\"w\":680,\"h\":383,\"resize\":\"fit\"},\"thumb\":{\"w\":150,\"h\":150,\"resize\":\"crop\"},\"medium\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"},\"large\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"}}}]},\"extended_entities\":{\"media\":[{\"id\":1209224663794159616,\"id_str\":\"1209224663794159616\",\"indices\":[154,177],\"media_url\":\"http:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"media_url_https\":\"https:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"url\":\"https:\\/\\/t.co\\/7LvVNVBN4X\",\"display_url\":\"pic.twitter.com\\/7LvVNVBN4X\",\"expanded_url\":\"https:\\/\\/twitter.com\\/dart_lang\\/status\\/1209224666646274048\\/photo\\/1\",\"type\":\"photo\",\"sizes\":{\"small\":{\"w\":680,\"h\":383,\"resize\":\"fit\"},\"thumb\":{\"w\":150,\"h\":150,\"resize\":\"crop\"},\"medium\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"},\"large\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"}}}]},\"source\":\"\\u003ca href=\\\"https:\\/\\/www.sprinklr.com\\\" rel=\\\"nofollow\\\"\\u003eSprinklr\\u003c\\/a\\u003e\",\"in_reply_to_status_id\":null,\"in_reply_to_status_id_str\":null,\"in_reply_to_user_id\":null,\"in_reply_to_user_id_str\":null,\"in_reply_to_screen_name\":null,\"user\":{\"id\":376585411,\"id_str\":\"376585411\"},\"geo\":null,\"coordinates\":null,\"place\":null,\"contributors\":null,\"is_quote_status\":false,\"retweet_count\":45,\"favorite_count\":211,\"favorited\":false,\"retweeted\":false,\"possibly_sensitive\":false,\"lang\":\"en\"},\"is_quote_status\":false,\"retweet_count\":45,\"favorite_count\":0,\"favorited\":false,\"retweeted\":false,\"lang\":\"en\"},{\"created_at\":\"Wed Dec 25 20:32:54 +0000 2019\",\"id\":1209935070464815104,\"id_str\":\"1209935070464815104\",\"full_text\":\"RT @dart_lang: \\ud83c\\udf89Dart has added a new feature called Extension Methods. \\u26a1\\n\\nNow you can add functionality to existing libraries. \\ud83d\\udcc1\\n \\nWatch he\\u2026\",\"truncated\":false,\"display_text_range\":[0,140],\"entities\":{\"hashtags\":[],\"symbols\":[],\"user_mentions\":[{\"screen_name\":\"dart_lang\",\"name\":\"Dart Language\",\"id\":376585411,\"id_str\":\"376585411\",\"indices\":[3,13]}],\"urls\":[]},\"source\":\"\\u003ca href=\\\"http:\\/\\/twitter.com\\/download\\/android\\\" rel=\\\"nofollow\\\"\\u003eTwitter for Android\\u003c\\/a\\u003e\",\"in_reply_to_status_id\":null,\"in_reply_to_status_id_str\":null,\"in_reply_to_user_id\":null,\"in_reply_to_user_id_str\":null,\"in_reply_to_screen_name\":null,\"user\":{\"id\":2372379606,\"id_str\":\"2372379606\"},\"geo\":null,\"coordinates\":null,\"place\":null,\"contributors\":null,\"retweeted_status\":{\"created_at\":\"Mon Dec 23 21:30:01 +0000 2019\",\"id\":1209224666646274048,\"id_str\":\"1209224666646274048\",\"full_text\":\"\\ud83c\\udf89Dart has added a new feature called Extension Methods. \\u26a1\\n\\nNow you can add functionality to existing libraries. \\ud83d\\udcc1\\n \\nWatch here \\u2192  https:\\/\\/t.co\\/bYcGRLBwbO https:\\/\\/t.co\\/7LvVNVBN4X\",\"truncated\":false,\"display_text_range\":[0,153],\"entities\":{\"hashtags\":[],\"symbols\":[],\"user_mentions\":[],\"urls\":[{\"url\":\"https:\\/\\/t.co\\/bYcGRLBwbO\",\"expanded_url\":\"https:\\/\\/goo.gle\\/399jCKI\",\"display_url\":\"goo.gle\\/399jCKI\",\"indices\":[130,153]}],\"media\":[{\"id\":1209224663794159616,\"id_str\":\"1209224663794159616\",\"indices\":[154,177],\"media_url\":\"http:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"media_url_https\":\"https:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"url\":\"https:\\/\\/t.co\\/7LvVNVBN4X\",\"display_url\":\"pic.twitter.com\\/7LvVNVBN4X\",\"expanded_url\":\"https:\\/\\/twitter.com\\/dart_lang\\/status\\/1209224666646274048\\/photo\\/1\",\"type\":\"photo\",\"sizes\":{\"small\":{\"w\":680,\"h\":383,\"resize\":\"fit\"},\"thumb\":{\"w\":150,\"h\":150,\"resize\":\"crop\"},\"medium\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"},\"large\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"}}}]},\"extended_entities\":{\"media\":[{\"id\":1209224663794159616,\"id_str\":\"1209224663794159616\",\"indices\":[154,177],\"media_url\":\"http:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"media_url_https\":\"https:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"url\":\"https:\\/\\/t.co\\/7LvVNVBN4X\",\"display_url\":\"pic.twitter.com\\/7LvVNVBN4X\",\"expanded_url\":\"https:\\/\\/twitter.com\\/dart_lang\\/status\\/1209224666646274048\\/photo\\/1\",\"type\":\"photo\",\"sizes\":{\"small\":{\"w\":680,\"h\":383,\"resize\":\"fit\"},\"thumb\":{\"w\":150,\"h\":150,\"resize\":\"crop\"},\"medium\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"},\"large\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"}}}]},\"source\":\"\\u003ca href=\\\"https:\\/\\/www.sprinklr.com\\\" rel=\\\"nofollow\\\"\\u003eSprinklr\\u003c\\/a\\u003e\",\"in_reply_to_status_id\":null,\"in_reply_to_status_id_str\":null,\"in_reply_to_user_id\":null,\"in_reply_to_user_id_str\":null,\"in_reply_to_screen_name\":null,\"user\":{\"id\":376585411,\"id_str\":\"376585411\"},\"geo\":null,\"coordinates\":null,\"place\":null,\"contributors\":null,\"is_quote_status\":false,\"retweet_count\":45,\"favorite_count\":211,\"favorited\":false,\"retweeted\":false,\"possibly_sensitive\":false,\"lang\":\"en\"},\"is_quote_status\":false,\"retweet_count\":45,\"favorite_count\":0,\"favorited\":false,\"retweeted\":false,\"lang\":\"en\"},{\"created_at\":\"Wed Dec 25 13:15:50 +0000 2019\",\"id\":1209825077115727878,\"id_str\":\"1209825077115727878\",\"full_text\":\"RT @dart_lang: \\ud83c\\udf89Dart has added a new feature called Extension Methods. \\u26a1\\n\\nNow you can add functionality to existing libraries. \\ud83d\\udcc1\\n \\nWatch he\\u2026\",\"truncated\":false,\"display_text_range\":[0,140],\"entities\":{\"hashtags\":[],\"symbols\":[],\"user_mentions\":[{\"screen_name\":\"dart_lang\",\"name\":\"Dart Language\",\"id\":376585411,\"id_str\":\"376585411\",\"indices\":[3,13]}],\"urls\":[]},\"source\":\"\\u003ca href=\\\"https:\\/\\/mobile.twitter.com\\\" rel=\\\"nofollow\\\"\\u003eTwitter Web App\\u003c\\/a\\u003e\",\"in_reply_to_status_id\":null,\"in_reply_to_status_id_str\":null,\"in_reply_to_user_id\":null,\"in_reply_to_user_id_str\":null,\"in_reply_to_screen_name\":null,\"user\":{\"id\":22119568,\"id_str\":\"22119568\"},\"geo\":null,\"coordinates\":null,\"place\":null,\"contributors\":null,\"retweeted_status\":{\"created_at\":\"Mon Dec 23 21:30:01 +0000 2019\",\"id\":1209224666646274048,\"id_str\":\"1209224666646274048\",\"full_text\":\"\\ud83c\\udf89Dart has added a new feature called Extension Methods. \\u26a1\\n\\nNow you can add functionality to existing libraries. \\ud83d\\udcc1\\n \\nWatch here \\u2192  https:\\/\\/t.co\\/bYcGRLBwbO https:\\/\\/t.co\\/7LvVNVBN4X\",\"truncated\":false,\"display_text_range\":[0,153],\"entities\":{\"hashtags\":[],\"symbols\":[],\"user_mentions\":[],\"urls\":[{\"url\":\"https:\\/\\/t.co\\/bYcGRLBwbO\",\"expanded_url\":\"https:\\/\\/goo.gle\\/399jCKI\",\"display_url\":\"goo.gle\\/399jCKI\",\"indices\":[130,153]}],\"media\":[{\"id\":1209224663794159616,\"id_str\":\"1209224663794159616\",\"indices\":[154,177],\"media_url\":\"http:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"media_url_https\":\"https:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"url\":\"https:\\/\\/t.co\\/7LvVNVBN4X\",\"display_url\":\"pic.twitter.com\\/7LvVNVBN4X\",\"expanded_url\":\"https:\\/\\/twitter.com\\/dart_lang\\/status\\/1209224666646274048\\/photo\\/1\",\"type\":\"photo\",\"sizes\":{\"small\":{\"w\":680,\"h\":383,\"resize\":\"fit\"},\"thumb\":{\"w\":150,\"h\":150,\"resize\":\"crop\"},\"medium\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"},\"large\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"}}}]},\"extended_entities\":{\"media\":[{\"id\":1209224663794159616,\"id_str\":\"1209224663794159616\",\"indices\":[154,177],\"media_url\":\"http:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"media_url_https\":\"https:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"url\":\"https:\\/\\/t.co\\/7LvVNVBN4X\",\"display_url\":\"pic.twitter.com\\/7LvVNVBN4X\",\"expanded_url\":\"https:\\/\\/twitter.com\\/dart_lang\\/status\\/1209224666646274048\\/photo\\/1\",\"type\":\"photo\",\"sizes\":{\"small\":{\"w\":680,\"h\":383,\"resize\":\"fit\"},\"thumb\":{\"w\":150,\"h\":150,\"resize\":\"crop\"},\"medium\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"},\"large\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"}}}]},\"source\":\"\\u003ca href=\\\"https:\\/\\/www.sprinklr.com\\\" rel=\\\"nofollow\\\"\\u003eSprinklr\\u003c\\/a\\u003e\",\"in_reply_to_status_id\":null,\"in_reply_to_status_id_str\":null,\"in_reply_to_user_id\":null,\"in_reply_to_user_id_str\":null,\"in_reply_to_screen_name\":null,\"user\":{\"id\":376585411,\"id_str\":\"376585411\"},\"geo\":null,\"coordinates\":null,\"place\":null,\"contributors\":null,\"is_quote_status\":false,\"retweet_count\":45,\"favorite_count\":211,\"favorited\":false,\"retweeted\":false,\"possibly_sensitive\":false,\"lang\":\"en\"},\"is_quote_status\":false,\"retweet_count\":45,\"favorite_count\":0,\"favorited\":false,\"retweeted\":false,\"lang\":\"en\"},{\"created_at\":\"Wed Dec 25 12:37:11 +0000 2019\",\"id\":1209815349606207490,\"id_str\":\"1209815349606207490\",\"full_text\":\"RT @dart_lang: \\ud83c\\udf89Dart has added a new feature called Extension Methods. \\u26a1\\n\\nNow you can add functionality to existing libraries. \\ud83d\\udcc1\\n \\nWatch he\\u2026\",\"truncated\":false,\"display_text_range\":[0,140],\"entities\":{\"hashtags\":[],\"symbols\":[],\"user_mentions\":[{\"screen_name\":\"dart_lang\",\"name\":\"Dart Language\",\"id\":376585411,\"id_str\":\"376585411\",\"indices\":[3,13]}],\"urls\":[]},\"source\":\"\\u003ca href=\\\"http:\\/\\/twitter.com\\/download\\/android\\\" rel=\\\"nofollow\\\"\\u003eTwitter for Android\\u003c\\/a\\u003e\",\"in_reply_to_status_id\":null,\"in_reply_to_status_id_str\":null,\"in_reply_to_user_id\":null,\"in_reply_to_user_id_str\":null,\"in_reply_to_screen_name\":null,\"user\":{\"id\":1207269032430329859,\"id_str\":\"1207269032430329859\"},\"geo\":null,\"coordinates\":null,\"place\":null,\"contributors\":null,\"retweeted_status\":{\"created_at\":\"Mon Dec 23 21:30:01 +0000 2019\",\"id\":1209224666646274048,\"id_str\":\"1209224666646274048\",\"full_text\":\"\\ud83c\\udf89Dart has added a new feature called Extension Methods. \\u26a1\\n\\nNow you can add functionality to existing libraries. \\ud83d\\udcc1\\n \\nWatch here \\u2192  https:\\/\\/t.co\\/bYcGRLBwbO https:\\/\\/t.co\\/7LvVNVBN4X\",\"truncated\":false,\"display_text_range\":[0,153],\"entities\":{\"hashtags\":[],\"symbols\":[],\"user_mentions\":[],\"urls\":[{\"url\":\"https:\\/\\/t.co\\/bYcGRLBwbO\",\"expanded_url\":\"https:\\/\\/goo.gle\\/399jCKI\",\"display_url\":\"goo.gle\\/399jCKI\",\"indices\":[130,153]}],\"media\":[{\"id\":1209224663794159616,\"id_str\":\"1209224663794159616\",\"indices\":[154,177],\"media_url\":\"http:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"media_url_https\":\"https:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"url\":\"https:\\/\\/t.co\\/7LvVNVBN4X\",\"display_url\":\"pic.twitter.com\\/7LvVNVBN4X\",\"expanded_url\":\"https:\\/\\/twitter.com\\/dart_lang\\/status\\/1209224666646274048\\/photo\\/1\",\"type\":\"photo\",\"sizes\":{\"small\":{\"w\":680,\"h\":383,\"resize\":\"fit\"},\"thumb\":{\"w\":150,\"h\":150,\"resize\":\"crop\"},\"medium\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"},\"large\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"}}}]},\"extended_entities\":{\"media\":[{\"id\":1209224663794159616,\"id_str\":\"1209224663794159616\",\"indices\":[154,177],\"media_url\":\"http:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"media_url_https\":\"https:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"url\":\"https:\\/\\/t.co\\/7LvVNVBN4X\",\"display_url\":\"pic.twitter.com\\/7LvVNVBN4X\",\"expanded_url\":\"https:\\/\\/twitter.com\\/dart_lang\\/status\\/1209224666646274048\\/photo\\/1\",\"type\":\"photo\",\"sizes\":{\"small\":{\"w\":680,\"h\":383,\"resize\":\"fit\"},\"thumb\":{\"w\":150,\"h\":150,\"resize\":\"crop\"},\"medium\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"},\"large\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"}}}]},\"source\":\"\\u003ca href=\\\"https:\\/\\/www.sprinklr.com\\\" rel=\\\"nofollow\\\"\\u003eSprinklr\\u003c\\/a\\u003e\",\"in_reply_to_status_id\":null,\"in_reply_to_status_id_str\":null,\"in_reply_to_user_id\":null,\"in_reply_to_user_id_str\":null,\"in_reply_to_screen_name\":null,\"user\":{\"id\":376585411,\"id_str\":\"376585411\"},\"geo\":null,\"coordinates\":null,\"place\":null,\"contributors\":null,\"is_quote_status\":false,\"retweet_count\":45,\"favorite_count\":211,\"favorited\":false,\"retweeted\":false,\"possibly_sensitive\":false,\"lang\":\"en\"},\"is_quote_status\":false,\"retweet_count\":45,\"favorite_count\":0,\"favorited\":false,\"retweeted\":false,\"lang\":\"en\"},{\"created_at\":\"Wed Dec 25 06:07:34 +0000 2019\",\"id\":1209717300120576000,\"id_str\":\"1209717300120576000\",\"full_text\":\"RT @dart_lang: \\ud83c\\udf89Dart has added a new feature called Extension Methods. \\u26a1\\n\\nNow you can add functionality to existing libraries. \\ud83d\\udcc1\\n \\nWatch he\\u2026\",\"truncated\":false,\"display_text_range\":[0,140],\"entities\":{\"hashtags\":[],\"symbols\":[],\"user_mentions\":[{\"screen_name\":\"dart_lang\",\"name\":\"Dart Language\",\"id\":376585411,\"id_str\":\"376585411\",\"indices\":[3,13]}],\"urls\":[]},\"source\":\"\\u003ca href=\\\"http:\\/\\/twitter.com\\/download\\/android\\\" rel=\\\"nofollow\\\"\\u003eTwitter for Android\\u003c\\/a\\u003e\",\"in_reply_to_status_id\":null,\"in_reply_to_status_id_str\":null,\"in_reply_to_user_id\":null,\"in_reply_to_user_id_str\":null,\"in_reply_to_screen_name\":null,\"user\":{\"id\":1433852347,\"id_str\":\"1433852347\"},\"geo\":null,\"coordinates\":null,\"place\":null,\"contributors\":null,\"retweeted_status\":{\"created_at\":\"Mon Dec 23 21:30:01 +0000 2019\",\"id\":1209224666646274048,\"id_str\":\"1209224666646274048\",\"full_text\":\"\\ud83c\\udf89Dart has added a new feature called Extension Methods. \\u26a1\\n\\nNow you can add functionality to existing libraries. \\ud83d\\udcc1\\n \\nWatch here \\u2192  https:\\/\\/t.co\\/bYcGRLBwbO https:\\/\\/t.co\\/7LvVNVBN4X\",\"truncated\":false,\"display_text_range\":[0,153],\"entities\":{\"hashtags\":[],\"symbols\":[],\"user_mentions\":[],\"urls\":[{\"url\":\"https:\\/\\/t.co\\/bYcGRLBwbO\",\"expanded_url\":\"https:\\/\\/goo.gle\\/399jCKI\",\"display_url\":\"goo.gle\\/399jCKI\",\"indices\":[130,153]}],\"media\":[{\"id\":1209224663794159616,\"id_str\":\"1209224663794159616\",\"indices\":[154,177],\"media_url\":\"http:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"media_url_https\":\"https:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"url\":\"https:\\/\\/t.co\\/7LvVNVBN4X\",\"display_url\":\"pic.twitter.com\\/7LvVNVBN4X\",\"expanded_url\":\"https:\\/\\/twitter.com\\/dart_lang\\/status\\/1209224666646274048\\/photo\\/1\",\"type\":\"photo\",\"sizes\":{\"small\":{\"w\":680,\"h\":383,\"resize\":\"fit\"},\"thumb\":{\"w\":150,\"h\":150,\"resize\":\"crop\"},\"medium\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"},\"large\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"}}}]},\"extended_entities\":{\"media\":[{\"id\":1209224663794159616,\"id_str\":\"1209224663794159616\",\"indices\":[154,177],\"media_url\":\"http:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"media_url_https\":\"https:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"url\":\"https:\\/\\/t.co\\/7LvVNVBN4X\",\"display_url\":\"pic.twitter.com\\/7LvVNVBN4X\",\"expanded_url\":\"https:\\/\\/twitter.com\\/dart_lang\\/status\\/1209224666646274048\\/photo\\/1\",\"type\":\"photo\",\"sizes\":{\"small\":{\"w\":680,\"h\":383,\"resize\":\"fit\"},\"thumb\":{\"w\":150,\"h\":150,\"resize\":\"crop\"},\"medium\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"},\"large\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"}}}]},\"source\":\"\\u003ca href=\\\"https:\\/\\/www.sprinklr.com\\\" rel=\\\"nofollow\\\"\\u003eSprinklr\\u003c\\/a\\u003e\",\"in_reply_to_status_id\":null,\"in_reply_to_status_id_str\":null,\"in_reply_to_user_id\":null,\"in_reply_to_user_id_str\":null,\"in_reply_to_screen_name\":null,\"user\":{\"id\":376585411,\"id_str\":\"376585411\"},\"geo\":null,\"coordinates\":null,\"place\":null,\"contributors\":null,\"is_quote_status\":false,\"retweet_count\":45,\"favorite_count\":211,\"favorited\":false,\"retweeted\":false,\"possibly_sensitive\":false,\"lang\":\"en\"},\"is_quote_status\":false,\"retweet_count\":45,\"favorite_count\":0,\"favorited\":false,\"retweeted\":false,\"lang\":\"en\"},{\"created_at\":\"Tue Dec 24 19:14:39 +0000 2019\",\"id\":1209552988047597573,\"id_str\":\"1209552988047597573\",\"full_text\":\"RT @dart_lang: \\ud83c\\udf89Dart has added a new feature called Extension Methods. \\u26a1\\n\\nNow you can add functionality to existing libraries. \\ud83d\\udcc1\\n \\nWatch he\\u2026\",\"truncated\":false,\"display_text_range\":[0,140],\"entities\":{\"hashtags\":[],\"symbols\":[],\"user_mentions\":[{\"screen_name\":\"dart_lang\",\"name\":\"Dart Language\",\"id\":376585411,\"id_str\":\"376585411\",\"indices\":[3,13]}],\"urls\":[]},\"source\":\"\\u003ca href=\\\"https:\\/\\/mobile.twitter.com\\\" rel=\\\"nofollow\\\"\\u003eTwitter Web App\\u003c\\/a\\u003e\",\"in_reply_to_status_id\":null,\"in_reply_to_status_id_str\":null,\"in_reply_to_user_id\":null,\"in_reply_to_user_id_str\":null,\"in_reply_to_screen_name\":null,\"user\":{\"id\":1202310730420281345,\"id_str\":\"1202310730420281345\"},\"geo\":null,\"coordinates\":null,\"place\":null,\"contributors\":null,\"retweeted_status\":{\"created_at\":\"Mon Dec 23 21:30:01 +0000 2019\",\"id\":1209224666646274048,\"id_str\":\"1209224666646274048\",\"full_text\":\"\\ud83c\\udf89Dart has added a new feature called Extension Methods. \\u26a1\\n\\nNow you can add functionality to existing libraries. \\ud83d\\udcc1\\n \\nWatch here \\u2192  https:\\/\\/t.co\\/bYcGRLBwbO https:\\/\\/t.co\\/7LvVNVBN4X\",\"truncated\":false,\"display_text_range\":[0,153],\"entities\":{\"hashtags\":[],\"symbols\":[],\"user_mentions\":[],\"urls\":[{\"url\":\"https:\\/\\/t.co\\/bYcGRLBwbO\",\"expanded_url\":\"https:\\/\\/goo.gle\\/399jCKI\",\"display_url\":\"goo.gle\\/399jCKI\",\"indices\":[130,153]}],\"media\":[{\"id\":1209224663794159616,\"id_str\":\"1209224663794159616\",\"indices\":[154,177],\"media_url\":\"http:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"media_url_https\":\"https:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"url\":\"https:\\/\\/t.co\\/7LvVNVBN4X\",\"display_url\":\"pic.twitter.com\\/7LvVNVBN4X\",\"expanded_url\":\"https:\\/\\/twitter.com\\/dart_lang\\/status\\/1209224666646274048\\/photo\\/1\",\"type\":\"photo\",\"sizes\":{\"small\":{\"w\":680,\"h\":383,\"resize\":\"fit\"},\"thumb\":{\"w\":150,\"h\":150,\"resize\":\"crop\"},\"medium\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"},\"large\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"}}}]},\"extended_entities\":{\"media\":[{\"id\":1209224663794159616,\"id_str\":\"1209224663794159616\",\"indices\":[154,177],\"media_url\":\"http:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"media_url_https\":\"https:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"url\":\"https:\\/\\/t.co\\/7LvVNVBN4X\",\"display_url\":\"pic.twitter.com\\/7LvVNVBN4X\",\"expanded_url\":\"https:\\/\\/twitter.com\\/dart_lang\\/status\\/1209224666646274048\\/photo\\/1\",\"type\":\"photo\",\"sizes\":{\"small\":{\"w\":680,\"h\":383,\"resize\":\"fit\"},\"thumb\":{\"w\":150,\"h\":150,\"resize\":\"crop\"},\"medium\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"},\"large\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"}}}]},\"source\":\"\\u003ca href=\\\"https:\\/\\/www.sprinklr.com\\\" rel=\\\"nofollow\\\"\\u003eSprinklr\\u003c\\/a\\u003e\",\"in_reply_to_status_id\":null,\"in_reply_to_status_id_str\":null,\"in_reply_to_user_id\":null,\"in_reply_to_user_id_str\":null,\"in_reply_to_screen_name\":null,\"user\":{\"id\":376585411,\"id_str\":\"376585411\"},\"geo\":null,\"coordinates\":null,\"place\":null,\"contributors\":null,\"is_quote_status\":false,\"retweet_count\":45,\"favorite_count\":211,\"favorited\":false,\"retweeted\":false,\"possibly_sensitive\":false,\"lang\":\"en\"},\"is_quote_status\":false,\"retweet_count\":45,\"favorite_count\":0,\"favorited\":false,\"retweeted\":false,\"lang\":\"en\"},{\"created_at\":\"Tue Dec 24 12:13:48 +0000 2019\",\"id\":1209447078717464576,\"id_str\":\"1209447078717464576\",\"full_text\":\"RT @dart_lang: \\ud83c\\udf89Dart has added a new feature called Extension Methods. \\u26a1\\n\\nNow you can add functionality to existing libraries. \\ud83d\\udcc1\\n \\nWatch he\\u2026\",\"truncated\":false,\"display_text_range\":[0,140],\"entities\":{\"hashtags\":[],\"symbols\":[],\"user_mentions\":[{\"screen_name\":\"dart_lang\",\"name\":\"Dart Language\",\"id\":376585411,\"id_str\":\"376585411\",\"indices\":[3,13]}],\"urls\":[]},\"source\":\"\\u003ca href=\\\"https:\\/\\/mobile.twitter.com\\\" rel=\\\"nofollow\\\"\\u003eTwitter Web App\\u003c\\/a\\u003e\",\"in_reply_to_status_id\":null,\"in_reply_to_status_id_str\":null,\"in_reply_to_user_id\":null,\"in_reply_to_user_id_str\":null,\"in_reply_to_screen_name\":null,\"user\":{\"id\":3544405702,\"id_str\":\"3544405702\"},\"geo\":null,\"coordinates\":null,\"place\":null,\"contributors\":null,\"retweeted_status\":{\"created_at\":\"Mon Dec 23 21:30:01 +0000 2019\",\"id\":1209224666646274048,\"id_str\":\"1209224666646274048\",\"full_text\":\"\\ud83c\\udf89Dart has added a new feature called Extension Methods. \\u26a1\\n\\nNow you can add functionality to existing libraries. \\ud83d\\udcc1\\n \\nWatch here \\u2192  https:\\/\\/t.co\\/bYcGRLBwbO https:\\/\\/t.co\\/7LvVNVBN4X\",\"truncated\":false,\"display_text_range\":[0,153],\"entities\":{\"hashtags\":[],\"symbols\":[],\"user_mentions\":[],\"urls\":[{\"url\":\"https:\\/\\/t.co\\/bYcGRLBwbO\",\"expanded_url\":\"https:\\/\\/goo.gle\\/399jCKI\",\"display_url\":\"goo.gle\\/399jCKI\",\"indices\":[130,153]}],\"media\":[{\"id\":1209224663794159616,\"id_str\":\"1209224663794159616\",\"indices\":[154,177],\"media_url\":\"http:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"media_url_https\":\"https:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"url\":\"https:\\/\\/t.co\\/7LvVNVBN4X\",\"display_url\":\"pic.twitter.com\\/7LvVNVBN4X\",\"expanded_url\":\"https:\\/\\/twitter.com\\/dart_lang\\/status\\/1209224666646274048\\/photo\\/1\",\"type\":\"photo\",\"sizes\":{\"small\":{\"w\":680,\"h\":383,\"resize\":\"fit\"},\"thumb\":{\"w\":150,\"h\":150,\"resize\":\"crop\"},\"medium\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"},\"large\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"}}}]},\"extended_entities\":{\"media\":[{\"id\":1209224663794159616,\"id_str\":\"1209224663794159616\",\"indices\":[154,177],\"media_url\":\"http:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"media_url_https\":\"https:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"url\":\"https:\\/\\/t.co\\/7LvVNVBN4X\",\"display_url\":\"pic.twitter.com\\/7LvVNVBN4X\",\"expanded_url\":\"https:\\/\\/twitter.com\\/dart_lang\\/status\\/1209224666646274048\\/photo\\/1\",\"type\":\"photo\",\"sizes\":{\"small\":{\"w\":680,\"h\":383,\"resize\":\"fit\"},\"thumb\":{\"w\":150,\"h\":150,\"resize\":\"crop\"},\"medium\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"},\"large\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"}}}]},\"source\":\"\\u003ca href=\\\"https:\\/\\/www.sprinklr.com\\\" rel=\\\"nofollow\\\"\\u003eSprinklr\\u003c\\/a\\u003e\",\"in_reply_to_status_id\":null,\"in_reply_to_status_id_str\":null,\"in_reply_to_user_id\":null,\"in_reply_to_user_id_str\":null,\"in_reply_to_screen_name\":null,\"user\":{\"id\":376585411,\"id_str\":\"376585411\"},\"geo\":null,\"coordinates\":null,\"place\":null,\"contributors\":null,\"is_quote_status\":false,\"retweet_count\":45,\"favorite_count\":211,\"favorited\":false,\"retweeted\":false,\"possibly_sensitive\":false,\"lang\":\"en\"},\"is_quote_status\":false,\"retweet_count\":45,\"favorite_count\":0,\"favorited\":false,\"retweeted\":false,\"lang\":\"en\"},{\"created_at\":\"Tue Dec 24 10:33:42 +0000 2019\",\"id\":1209421885387100161,\"id_str\":\"1209421885387100161\",\"full_text\":\"RT @dart_lang: \\ud83c\\udf89Dart has added a new feature called Extension Methods. \\u26a1\\n\\nNow you can add functionality to existing libraries. \\ud83d\\udcc1\\n \\nWatch he\\u2026\",\"truncated\":false,\"display_text_range\":[0,140],\"entities\":{\"hashtags\":[],\"symbols\":[],\"user_mentions\":[{\"screen_name\":\"dart_lang\",\"name\":\"Dart Language\",\"id\":376585411,\"id_str\":\"376585411\",\"indices\":[3,13]}],\"urls\":[]},\"source\":\"\\u003ca href=\\\"http:\\/\\/twitter.com\\/download\\/android\\\" rel=\\\"nofollow\\\"\\u003eTwitter for Android\\u003c\\/a\\u003e\",\"in_reply_to_status_id\":null,\"in_reply_to_status_id_str\":null,\"in_reply_to_user_id\":null,\"in_reply_to_user_id_str\":null,\"in_reply_to_screen_name\":null,\"user\":{\"id\":2203994160,\"id_str\":\"2203994160\"},\"geo\":null,\"coordinates\":null,\"place\":null,\"contributors\":null,\"retweeted_status\":{\"created_at\":\"Mon Dec 23 21:30:01 +0000 2019\",\"id\":1209224666646274048,\"id_str\":\"1209224666646274048\",\"full_text\":\"\\ud83c\\udf89Dart has added a new feature called Extension Methods. \\u26a1\\n\\nNow you can add functionality to existing libraries. \\ud83d\\udcc1\\n \\nWatch here \\u2192  https:\\/\\/t.co\\/bYcGRLBwbO https:\\/\\/t.co\\/7LvVNVBN4X\",\"truncated\":false,\"display_text_range\":[0,153],\"entities\":{\"hashtags\":[],\"symbols\":[],\"user_mentions\":[],\"urls\":[{\"url\":\"https:\\/\\/t.co\\/bYcGRLBwbO\",\"expanded_url\":\"https:\\/\\/goo.gle\\/399jCKI\",\"display_url\":\"goo.gle\\/399jCKI\",\"indices\":[130,153]}],\"media\":[{\"id\":1209224663794159616,\"id_str\":\"1209224663794159616\",\"indices\":[154,177],\"media_url\":\"http:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"media_url_https\":\"https:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"url\":\"https:\\/\\/t.co\\/7LvVNVBN4X\",\"display_url\":\"pic.twitter.com\\/7LvVNVBN4X\",\"expanded_url\":\"https:\\/\\/twitter.com\\/dart_lang\\/status\\/1209224666646274048\\/photo\\/1\",\"type\":\"photo\",\"sizes\":{\"small\":{\"w\":680,\"h\":383,\"resize\":\"fit\"},\"thumb\":{\"w\":150,\"h\":150,\"resize\":\"crop\"},\"medium\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"},\"large\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"}}}]},\"extended_entities\":{\"media\":[{\"id\":1209224663794159616,\"id_str\":\"1209224663794159616\",\"indices\":[154,177],\"media_url\":\"http:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"media_url_https\":\"https:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"url\":\"https:\\/\\/t.co\\/7LvVNVBN4X\",\"display_url\":\"pic.twitter.com\\/7LvVNVBN4X\",\"expanded_url\":\"https:\\/\\/twitter.com\\/dart_lang\\/status\\/1209224666646274048\\/photo\\/1\",\"type\":\"photo\",\"sizes\":{\"small\":{\"w\":680,\"h\":383,\"resize\":\"fit\"},\"thumb\":{\"w\":150,\"h\":150,\"resize\":\"crop\"},\"medium\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"},\"large\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"}}}]},\"source\":\"\\u003ca href=\\\"https:\\/\\/www.sprinklr.com\\\" rel=\\\"nofollow\\\"\\u003eSprinklr\\u003c\\/a\\u003e\",\"in_reply_to_status_id\":null,\"in_reply_to_status_id_str\":null,\"in_reply_to_user_id\":null,\"in_reply_to_user_id_str\":null,\"in_reply_to_screen_name\":null,\"user\":{\"id\":376585411,\"id_str\":\"376585411\"},\"geo\":null,\"coordinates\":null,\"place\":null,\"contributors\":null,\"is_quote_status\":false,\"retweet_count\":45,\"favorite_count\":211,\"favorited\":false,\"retweeted\":false,\"possibly_sensitive\":false,\"lang\":\"en\"},\"is_quote_status\":false,\"retweet_count\":45,\"favorite_count\":0,\"favorited\":false,\"retweeted\":false,\"lang\":\"en\"},{\"created_at\":\"Tue Dec 24 10:19:17 +0000 2019\",\"id\":1209418258362896387,\"id_str\":\"1209418258362896387\",\"full_text\":\"RT @dart_lang: \\ud83c\\udf89Dart has added a new feature called Extension Methods. \\u26a1\\n\\nNow you can add functionality to existing libraries. \\ud83d\\udcc1\\n \\nWatch he\\u2026\",\"truncated\":false,\"display_text_range\":[0,140],\"entities\":{\"hashtags\":[],\"symbols\":[],\"user_mentions\":[{\"screen_name\":\"dart_lang\",\"name\":\"Dart Language\",\"id\":376585411,\"id_str\":\"376585411\",\"indices\":[3,13]}],\"urls\":[]},\"source\":\"\\u003ca href=\\\"http:\\/\\/twitter.com\\/download\\/iphone\\\" rel=\\\"nofollow\\\"\\u003eTwitter for iPhone\\u003c\\/a\\u003e\",\"in_reply_to_status_id\":null,\"in_reply_to_status_id_str\":null,\"in_reply_to_user_id\":null,\"in_reply_to_user_id_str\":null,\"in_reply_to_screen_name\":null,\"user\":{\"id\":7630592,\"id_str\":\"7630592\"},\"geo\":null,\"coordinates\":null,\"place\":null,\"contributors\":null,\"retweeted_status\":{\"created_at\":\"Mon Dec 23 21:30:01 +0000 2019\",\"id\":1209224666646274048,\"id_str\":\"1209224666646274048\",\"full_text\":\"\\ud83c\\udf89Dart has added a new feature called Extension Methods. \\u26a1\\n\\nNow you can add functionality to existing libraries. \\ud83d\\udcc1\\n \\nWatch here \\u2192  https:\\/\\/t.co\\/bYcGRLBwbO https:\\/\\/t.co\\/7LvVNVBN4X\",\"truncated\":false,\"display_text_range\":[0,153],\"entities\":{\"hashtags\":[],\"symbols\":[],\"user_mentions\":[],\"urls\":[{\"url\":\"https:\\/\\/t.co\\/bYcGRLBwbO\",\"expanded_url\":\"https:\\/\\/goo.gle\\/399jCKI\",\"display_url\":\"goo.gle\\/399jCKI\",\"indices\":[130,153]}],\"media\":[{\"id\":1209224663794159616,\"id_str\":\"1209224663794159616\",\"indices\":[154,177],\"media_url\":\"http:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"media_url_https\":\"https:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"url\":\"https:\\/\\/t.co\\/7LvVNVBN4X\",\"display_url\":\"pic.twitter.com\\/7LvVNVBN4X\",\"expanded_url\":\"https:\\/\\/twitter.com\\/dart_lang\\/status\\/1209224666646274048\\/photo\\/1\",\"type\":\"photo\",\"sizes\":{\"small\":{\"w\":680,\"h\":383,\"resize\":\"fit\"},\"thumb\":{\"w\":150,\"h\":150,\"resize\":\"crop\"},\"medium\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"},\"large\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"}}}]},\"extended_entities\":{\"media\":[{\"id\":1209224663794159616,\"id_str\":\"1209224663794159616\",\"indices\":[154,177],\"media_url\":\"http:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"media_url_https\":\"https:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"url\":\"https:\\/\\/t.co\\/7LvVNVBN4X\",\"display_url\":\"pic.twitter.com\\/7LvVNVBN4X\",\"expanded_url\":\"https:\\/\\/twitter.com\\/dart_lang\\/status\\/1209224666646274048\\/photo\\/1\",\"type\":\"photo\",\"sizes\":{\"small\":{\"w\":680,\"h\":383,\"resize\":\"fit\"},\"thumb\":{\"w\":150,\"h\":150,\"resize\":\"crop\"},\"medium\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"},\"large\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"}}}]},\"source\":\"\\u003ca href=\\\"https:\\/\\/www.sprinklr.com\\\" rel=\\\"nofollow\\\"\\u003eSprinklr\\u003c\\/a\\u003e\",\"in_reply_to_status_id\":null,\"in_reply_to_status_id_str\":null,\"in_reply_to_user_id\":null,\"in_reply_to_user_id_str\":null,\"in_reply_to_screen_name\":null,\"user\":{\"id\":376585411,\"id_str\":\"376585411\"},\"geo\":null,\"coordinates\":null,\"place\":null,\"contributors\":null,\"is_quote_status\":false,\"retweet_count\":45,\"favorite_count\":211,\"favorited\":false,\"retweeted\":false,\"possibly_sensitive\":false,\"lang\":\"en\"},\"is_quote_status\":false,\"retweet_count\":45,\"favorite_count\":0,\"favorited\":false,\"retweeted\":false,\"lang\":\"en\"},{\"created_at\":\"Tue Dec 24 09:27:25 +0000 2019\",\"id\":1209405206351343617,\"id_str\":\"1209405206351343617\",\"full_text\":\"RT @dart_lang: \\ud83c\\udf89Dart has added a new feature called Extension Methods. \\u26a1\\n\\nNow you can add functionality to existing libraries. \\ud83d\\udcc1\\n \\nWatch he\\u2026\",\"truncated\":false,\"display_text_range\":[0,140],\"entities\":{\"hashtags\":[],\"symbols\":[],\"user_mentions\":[{\"screen_name\":\"dart_lang\",\"name\":\"Dart Language\",\"id\":376585411,\"id_str\":\"376585411\",\"indices\":[3,13]}],\"urls\":[]},\"source\":\"\\u003ca href=\\\"http:\\/\\/twitter.com\\/download\\/iphone\\\" rel=\\\"nofollow\\\"\\u003eTwitter for iPhone\\u003c\\/a\\u003e\",\"in_reply_to_status_id\":null,\"in_reply_to_status_id_str\":null,\"in_reply_to_user_id\":null,\"in_reply_to_user_id_str\":null,\"in_reply_to_screen_name\":null,\"user\":{\"id\":2165157812,\"id_str\":\"2165157812\"},\"geo\":null,\"coordinates\":null,\"place\":null,\"contributors\":null,\"retweeted_status\":{\"created_at\":\"Mon Dec 23 21:30:01 +0000 2019\",\"id\":1209224666646274048,\"id_str\":\"1209224666646274048\",\"full_text\":\"\\ud83c\\udf89Dart has added a new feature called Extension Methods. \\u26a1\\n\\nNow you can add functionality to existing libraries. \\ud83d\\udcc1\\n \\nWatch here \\u2192  https:\\/\\/t.co\\/bYcGRLBwbO https:\\/\\/t.co\\/7LvVNVBN4X\",\"truncated\":false,\"display_text_range\":[0,153],\"entities\":{\"hashtags\":[],\"symbols\":[],\"user_mentions\":[],\"urls\":[{\"url\":\"https:\\/\\/t.co\\/bYcGRLBwbO\",\"expanded_url\":\"https:\\/\\/goo.gle\\/399jCKI\",\"display_url\":\"goo.gle\\/399jCKI\",\"indices\":[130,153]}],\"media\":[{\"id\":1209224663794159616,\"id_str\":\"1209224663794159616\",\"indices\":[154,177],\"media_url\":\"http:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"media_url_https\":\"https:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"url\":\"https:\\/\\/t.co\\/7LvVNVBN4X\",\"display_url\":\"pic.twitter.com\\/7LvVNVBN4X\",\"expanded_url\":\"https:\\/\\/twitter.com\\/dart_lang\\/status\\/1209224666646274048\\/photo\\/1\",\"type\":\"photo\",\"sizes\":{\"small\":{\"w\":680,\"h\":383,\"resize\":\"fit\"},\"thumb\":{\"w\":150,\"h\":150,\"resize\":\"crop\"},\"medium\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"},\"large\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"}}}]},\"extended_entities\":{\"media\":[{\"id\":1209224663794159616,\"id_str\":\"1209224663794159616\",\"indices\":[154,177],\"media_url\":\"http:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"media_url_https\":\"https:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"url\":\"https:\\/\\/t.co\\/7LvVNVBN4X\",\"display_url\":\"pic.twitter.com\\/7LvVNVBN4X\",\"expanded_url\":\"https:\\/\\/twitter.com\\/dart_lang\\/status\\/1209224666646274048\\/photo\\/1\",\"type\":\"photo\",\"sizes\":{\"small\":{\"w\":680,\"h\":383,\"resize\":\"fit\"},\"thumb\":{\"w\":150,\"h\":150,\"resize\":\"crop\"},\"medium\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"},\"large\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"}}}]},\"source\":\"\\u003ca href=\\\"https:\\/\\/www.sprinklr.com\\\" rel=\\\"nofollow\\\"\\u003eSprinklr\\u003c\\/a\\u003e\",\"in_reply_to_status_id\":null,\"in_reply_to_status_id_str\":null,\"in_reply_to_user_id\":null,\"in_reply_to_user_id_str\":null,\"in_reply_to_screen_name\":null,\"user\":{\"id\":376585411,\"id_str\":\"376585411\"},\"geo\":null,\"coordinates\":null,\"place\":null,\"contributors\":null,\"is_quote_status\":false,\"retweet_count\":45,\"favorite_count\":211,\"favorited\":false,\"retweeted\":false,\"possibly_sensitive\":false,\"lang\":\"en\"},\"is_quote_status\":false,\"retweet_count\":45,\"favorite_count\":0,\"favorited\":false,\"retweeted\":false,\"lang\":\"en\"},{\"created_at\":\"Tue Dec 24 09:27:03 +0000 2019\",\"id\":1209405112290095105,\"id_str\":\"1209405112290095105\",\"full_text\":\"RT @dart_lang: \\ud83c\\udf89Dart has added a new feature called Extension Methods. \\u26a1\\n\\nNow you can add functionality to existing libraries. \\ud83d\\udcc1\\n \\nWatch he\\u2026\",\"truncated\":false,\"display_text_range\":[0,140],\"entities\":{\"hashtags\":[],\"symbols\":[],\"user_mentions\":[{\"screen_name\":\"dart_lang\",\"name\":\"Dart Language\",\"id\":376585411,\"id_str\":\"376585411\",\"indices\":[3,13]}],\"urls\":[]},\"source\":\"\\u003ca href=\\\"https:\\/\\/mobile.twitter.com\\\" rel=\\\"nofollow\\\"\\u003eTwitter Web App\\u003c\\/a\\u003e\",\"in_reply_to_status_id\":null,\"in_reply_to_status_id_str\":null,\"in_reply_to_user_id\":null,\"in_reply_to_user_id_str\":null,\"in_reply_to_screen_name\":null,\"user\":{\"id\":130194713,\"id_str\":\"130194713\"},\"geo\":null,\"coordinates\":null,\"place\":null,\"contributors\":null,\"retweeted_status\":{\"created_at\":\"Mon Dec 23 21:30:01 +0000 2019\",\"id\":1209224666646274048,\"id_str\":\"1209224666646274048\",\"full_text\":\"\\ud83c\\udf89Dart has added a new feature called Extension Methods. \\u26a1\\n\\nNow you can add functionality to existing libraries. \\ud83d\\udcc1\\n \\nWatch here \\u2192  https:\\/\\/t.co\\/bYcGRLBwbO https:\\/\\/t.co\\/7LvVNVBN4X\",\"truncated\":false,\"display_text_range\":[0,153],\"entities\":{\"hashtags\":[],\"symbols\":[],\"user_mentions\":[],\"urls\":[{\"url\":\"https:\\/\\/t.co\\/bYcGRLBwbO\",\"expanded_url\":\"https:\\/\\/goo.gle\\/399jCKI\",\"display_url\":\"goo.gle\\/399jCKI\",\"indices\":[130,153]}],\"media\":[{\"id\":1209224663794159616,\"id_str\":\"1209224663794159616\",\"indices\":[154,177],\"media_url\":\"http:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"media_url_https\":\"https:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"url\":\"https:\\/\\/t.co\\/7LvVNVBN4X\",\"display_url\":\"pic.twitter.com\\/7LvVNVBN4X\",\"expanded_url\":\"https:\\/\\/twitter.com\\/dart_lang\\/status\\/1209224666646274048\\/photo\\/1\",\"type\":\"photo\",\"sizes\":{\"small\":{\"w\":680,\"h\":383,\"resize\":\"fit\"},\"thumb\":{\"w\":150,\"h\":150,\"resize\":\"crop\"},\"medium\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"},\"large\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"}}}]},\"extended_entities\":{\"media\":[{\"id\":1209224663794159616,\"id_str\":\"1209224663794159616\",\"indices\":[154,177],\"media_url\":\"http:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"media_url_https\":\"https:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"url\":\"https:\\/\\/t.co\\/7LvVNVBN4X\",\"display_url\":\"pic.twitter.com\\/7LvVNVBN4X\",\"expanded_url\":\"https:\\/\\/twitter.com\\/dart_lang\\/status\\/1209224666646274048\\/photo\\/1\",\"type\":\"photo\",\"sizes\":{\"small\":{\"w\":680,\"h\":383,\"resize\":\"fit\"},\"thumb\":{\"w\":150,\"h\":150,\"resize\":\"crop\"},\"medium\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"},\"large\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"}}}]},\"source\":\"\\u003ca href=\\\"https:\\/\\/www.sprinklr.com\\\" rel=\\\"nofollow\\\"\\u003eSprinklr\\u003c\\/a\\u003e\",\"in_reply_to_status_id\":null,\"in_reply_to_status_id_str\":null,\"in_reply_to_user_id\":null,\"in_reply_to_user_id_str\":null,\"in_reply_to_screen_name\":null,\"user\":{\"id\":376585411,\"id_str\":\"376585411\"},\"geo\":null,\"coordinates\":null,\"place\":null,\"contributors\":null,\"is_quote_status\":false,\"retweet_count\":45,\"favorite_count\":211,\"favorited\":false,\"retweeted\":false,\"possibly_sensitive\":false,\"lang\":\"en\"},\"is_quote_status\":false,\"retweet_count\":45,\"favorite_count\":0,\"favorited\":false,\"retweeted\":false,\"lang\":\"en\"},{\"created_at\":\"Tue Dec 24 09:11:54 +0000 2019\",\"id\":1209401299869032449,\"id_str\":\"1209401299869032449\",\"full_text\":\"RT @dart_lang: \\ud83c\\udf89Dart has added a new feature called Extension Methods. \\u26a1\\n\\nNow you can add functionality to existing libraries. \\ud83d\\udcc1\\n \\nWatch he\\u2026\",\"truncated\":false,\"display_text_range\":[0,140],\"entities\":{\"hashtags\":[],\"symbols\":[],\"user_mentions\":[{\"screen_name\":\"dart_lang\",\"name\":\"Dart Language\",\"id\":376585411,\"id_str\":\"376585411\",\"indices\":[3,13]}],\"urls\":[]},\"source\":\"\\u003ca href=\\\"http:\\/\\/twitter.com\\/download\\/android\\\" rel=\\\"nofollow\\\"\\u003eTwitter for Android\\u003c\\/a\\u003e\",\"in_reply_to_status_id\":null,\"in_reply_to_status_id_str\":null,\"in_reply_to_user_id\":null,\"in_reply_to_user_id_str\":null,\"in_reply_to_screen_name\":null,\"user\":{\"id\":1184812725760909312,\"id_str\":\"1184812725760909312\"},\"geo\":null,\"coordinates\":null,\"place\":null,\"contributors\":null,\"retweeted_status\":{\"created_at\":\"Mon Dec 23 21:30:01 +0000 2019\",\"id\":1209224666646274048,\"id_str\":\"1209224666646274048\",\"full_text\":\"\\ud83c\\udf89Dart has added a new feature called Extension Methods. \\u26a1\\n\\nNow you can add functionality to existing libraries. \\ud83d\\udcc1\\n \\nWatch here \\u2192  https:\\/\\/t.co\\/bYcGRLBwbO https:\\/\\/t.co\\/7LvVNVBN4X\",\"truncated\":false,\"display_text_range\":[0,153],\"entities\":{\"hashtags\":[],\"symbols\":[],\"user_mentions\":[],\"urls\":[{\"url\":\"https:\\/\\/t.co\\/bYcGRLBwbO\",\"expanded_url\":\"https:\\/\\/goo.gle\\/399jCKI\",\"display_url\":\"goo.gle\\/399jCKI\",\"indices\":[130,153]}],\"media\":[{\"id\":1209224663794159616,\"id_str\":\"1209224663794159616\",\"indices\":[154,177],\"media_url\":\"http:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"media_url_https\":\"https:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"url\":\"https:\\/\\/t.co\\/7LvVNVBN4X\",\"display_url\":\"pic.twitter.com\\/7LvVNVBN4X\",\"expanded_url\":\"https:\\/\\/twitter.com\\/dart_lang\\/status\\/1209224666646274048\\/photo\\/1\",\"type\":\"photo\",\"sizes\":{\"small\":{\"w\":680,\"h\":383,\"resize\":\"fit\"},\"thumb\":{\"w\":150,\"h\":150,\"resize\":\"crop\"},\"medium\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"},\"large\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"}}}]},\"extended_entities\":{\"media\":[{\"id\":1209224663794159616,\"id_str\":\"1209224663794159616\",\"indices\":[154,177],\"media_url\":\"http:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"media_url_https\":\"https:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"url\":\"https:\\/\\/t.co\\/7LvVNVBN4X\",\"display_url\":\"pic.twitter.com\\/7LvVNVBN4X\",\"expanded_url\":\"https:\\/\\/twitter.com\\/dart_lang\\/status\\/1209224666646274048\\/photo\\/1\",\"type\":\"photo\",\"sizes\":{\"small\":{\"w\":680,\"h\":383,\"resize\":\"fit\"},\"thumb\":{\"w\":150,\"h\":150,\"resize\":\"crop\"},\"medium\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"},\"large\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"}}}]},\"source\":\"\\u003ca href=\\\"https:\\/\\/www.sprinklr.com\\\" rel=\\\"nofollow\\\"\\u003eSprinklr\\u003c\\/a\\u003e\",\"in_reply_to_status_id\":null,\"in_reply_to_status_id_str\":null,\"in_reply_to_user_id\":null,\"in_reply_to_user_id_str\":null,\"in_reply_to_screen_name\":null,\"user\":{\"id\":376585411,\"id_str\":\"376585411\"},\"geo\":null,\"coordinates\":null,\"place\":null,\"contributors\":null,\"is_quote_status\":false,\"retweet_count\":45,\"favorite_count\":211,\"favorited\":false,\"retweeted\":false,\"possibly_sensitive\":false,\"lang\":\"en\"},\"is_quote_status\":false,\"retweet_count\":45,\"favorite_count\":0,\"favorited\":false,\"retweeted\":false,\"lang\":\"en\"}]''';

const _retweetsOfMeResponse =
    '''[{\"created_at\":\"Wed Jul 24 09:45:56 +0000 2019\",\"id\":1153964521469501440,\"id_str\":\"1153964521469501440\",\"full_text\":\"ayo\",\"truncated\":false,\"display_text_range\":[0,3],\"entities\":{\"hashtags\":[],\"symbols\":[],\"user_mentions\":[],\"urls\":[]},\"source\":\"\\u003ca href=\\\"http:\\/\\/robertodoering.com\\\" rel=\\\"nofollow\\\"\\u003eHarpy for Twitter\\u003c\\/a\\u003e\",\"in_reply_to_status_id\":null,\"in_reply_to_status_id_str\":null,\"in_reply_to_user_id\":null,\"in_reply_to_user_id_str\":null,\"in_reply_to_screen_name\":null,\"user\":{\"id\":1068105113284300800,\"id_str\":\"1068105113284300800\",\"name\":\"Harpy App\",\"screen_name\":\"harpy_app\",\"location\":\"North Pole, AK\",\"description\":\"please don't hurt me\",\"url\":\"https:\\/\\/t.co\\/cHZdP4MpC4\",\"entities\":{\"url\":{\"urls\":[{\"url\":\"https:\\/\\/t.co\\/cHZdP4MpC4\",\"expanded_url\":\"http:\\/\\/google.com\",\"display_url\":\"google.com\",\"indices\":[0,23]}]},\"description\":{\"urls\":[]}},\"protected\":false,\"followers_count\":1,\"friends_count\":10,\"listed_count\":0,\"created_at\":\"Thu Nov 29 11:31:18 +0000 2018\",\"favourites_count\":14,\"utc_offset\":null,\"time_zone\":null,\"geo_enabled\":false,\"verified\":false,\"statuses_count\":45,\"lang\":null,\"contributors_enabled\":false,\"is_translator\":false,\"is_translation_enabled\":false,\"profile_background_color\":\"000000\",\"profile_background_image_url\":\"http:\\/\\/abs.twimg.com\\/images\\/themes\\/theme1\\/bg.png\",\"profile_background_image_url_https\":\"https:\\/\\/abs.twimg.com\\/images\\/themes\\/theme1\\/bg.png\",\"profile_background_tile\":false,\"profile_image_url\":\"http:\\/\\/abs.twimg.com\\/sticky\\/default_profile_images\\/default_profile_normal.png\",\"profile_image_url_https\":\"https:\\/\\/abs.twimg.com\\/sticky\\/default_profile_images\\/default_profile_normal.png\",\"profile_link_color\":\"981CEB\",\"profile_sidebar_border_color\":\"000000\",\"profile_sidebar_fill_color\":\"000000\",\"profile_text_color\":\"000000\",\"profile_use_background_image\":false,\"has_extended_profile\":true,\"default_profile\":false,\"default_profile_image\":true,\"following\":false,\"follow_request_sent\":false,\"notifications\":false,\"translator_type\":\"none\"},\"geo\":null,\"coordinates\":null,\"place\":null,\"contributors\":null,\"is_quote_status\":false,\"retweet_count\":1,\"favorite_count\":1,\"favorited\":true,\"retweeted\":true,\"lang\":\"und\"},{\"created_at\":\"Thu Nov 29 11:37:19 +0000 2018\",\"id\":1068106630213046273,\"id_str\":\"1068106630213046273\",\"full_text\":\"unicode test \\u00e4\\u00f6\\u00fc \\ud83e\\udddf\\u200d\\u2642\\ufe0f\",\"truncated\":false,\"display_text_range\":[0,21],\"entities\":{\"hashtags\":[],\"symbols\":[],\"user_mentions\":[],\"urls\":[]},\"source\":\"\\u003ca href=\\\"http:\\/\\/twitter.com\\\" rel=\\\"nofollow\\\"\\u003eTwitter Web Client\\u003c\\/a\\u003e\",\"in_reply_to_status_id\":null,\"in_reply_to_status_id_str\":null,\"in_reply_to_user_id\":null,\"in_reply_to_user_id_str\":null,\"in_reply_to_screen_name\":null,\"user\":{\"id\":1068105113284300800,\"id_str\":\"1068105113284300800\",\"name\":\"Harpy App\",\"screen_name\":\"harpy_app\",\"location\":\"North Pole, AK\",\"description\":\"please don't hurt me\",\"url\":\"https:\\/\\/t.co\\/cHZdP4MpC4\",\"entities\":{\"url\":{\"urls\":[{\"url\":\"https:\\/\\/t.co\\/cHZdP4MpC4\",\"expanded_url\":\"http:\\/\\/google.com\",\"display_url\":\"google.com\",\"indices\":[0,23]}]},\"description\":{\"urls\":[]}},\"protected\":false,\"followers_count\":1,\"friends_count\":10,\"listed_count\":0,\"created_at\":\"Thu Nov 29 11:31:18 +0000 2018\",\"favourites_count\":14,\"utc_offset\":null,\"time_zone\":null,\"geo_enabled\":false,\"verified\":false,\"statuses_count\":45,\"lang\":null,\"contributors_enabled\":false,\"is_translator\":false,\"is_translation_enabled\":false,\"profile_background_color\":\"000000\",\"profile_background_image_url\":\"http:\\/\\/abs.twimg.com\\/images\\/themes\\/theme1\\/bg.png\",\"profile_background_image_url_https\":\"https:\\/\\/abs.twimg.com\\/images\\/themes\\/theme1\\/bg.png\",\"profile_background_tile\":false,\"profile_image_url\":\"http:\\/\\/abs.twimg.com\\/sticky\\/default_profile_images\\/default_profile_normal.png\",\"profile_image_url_https\":\"https:\\/\\/abs.twimg.com\\/sticky\\/default_profile_images\\/default_profile_normal.png\",\"profile_link_color\":\"981CEB\",\"profile_sidebar_border_color\":\"000000\",\"profile_sidebar_fill_color\":\"000000\",\"profile_text_color\":\"000000\",\"profile_use_background_image\":false,\"has_extended_profile\":true,\"default_profile\":false,\"default_profile_image\":true,\"following\":false,\"follow_request_sent\":false,\"notifications\":false,\"translator_type\":\"none\"},\"geo\":null,\"coordinates\":null,\"place\":null,\"contributors\":null,\"is_quote_status\":false,\"retweet_count\":1,\"favorite_count\":1,\"favorited\":true,\"retweeted\":true,\"lang\":\"et\"}]''';

const _createFavoriteResponse =
    '''{\"created_at\":\"Mon Dec 23 21:30:01 +0000 2019\",\"id\":1209224666646274048,\"id_str\":\"1209224666646274048\",\"full_text\":\"\\ud83c\\udf89Dart has added a new feature called Extension Methods. \\u26a1\\n\\nNow you can add functionality to existing libraries. \\ud83d\\udcc1\\n \\nWatch here \\u2192  https:\\/\\/t.co\\/bYcGRLBwbO https:\\/\\/t.co\\/7LvVNVBN4X\",\"truncated\":false,\"display_text_range\":[0,153],\"entities\":{\"hashtags\":[],\"symbols\":[],\"user_mentions\":[],\"urls\":[{\"url\":\"https:\\/\\/t.co\\/bYcGRLBwbO\",\"expanded_url\":\"https:\\/\\/goo.gle\\/399jCKI\",\"display_url\":\"goo.gle\\/399jCKI\",\"indices\":[130,153]}],\"media\":[{\"id\":1209224663794159616,\"id_str\":\"1209224663794159616\",\"indices\":[154,177],\"media_url\":\"http:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"media_url_https\":\"https:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"url\":\"https:\\/\\/t.co\\/7LvVNVBN4X\",\"display_url\":\"pic.twitter.com\\/7LvVNVBN4X\",\"expanded_url\":\"https:\\/\\/twitter.com\\/dart_lang\\/status\\/1209224666646274048\\/photo\\/1\",\"type\":\"photo\",\"sizes\":{\"small\":{\"w\":680,\"h\":383,\"resize\":\"fit\"},\"thumb\":{\"w\":150,\"h\":150,\"resize\":\"crop\"},\"medium\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"},\"large\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"}}}]},\"extended_entities\":{\"media\":[{\"id\":1209224663794159616,\"id_str\":\"1209224663794159616\",\"indices\":[154,177],\"media_url\":\"http:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"media_url_https\":\"https:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"url\":\"https:\\/\\/t.co\\/7LvVNVBN4X\",\"display_url\":\"pic.twitter.com\\/7LvVNVBN4X\",\"expanded_url\":\"https:\\/\\/twitter.com\\/dart_lang\\/status\\/1209224666646274048\\/photo\\/1\",\"type\":\"photo\",\"sizes\":{\"small\":{\"w\":680,\"h\":383,\"resize\":\"fit\"},\"thumb\":{\"w\":150,\"h\":150,\"resize\":\"crop\"},\"medium\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"},\"large\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"}}}]},\"source\":\"\\u003ca href=\\\"https:\\/\\/www.sprinklr.com\\\" rel=\\\"nofollow\\\"\\u003eSprinklr\\u003c\\/a\\u003e\",\"in_reply_to_status_id\":null,\"in_reply_to_status_id_str\":null,\"in_reply_to_user_id\":null,\"in_reply_to_user_id_str\":null,\"in_reply_to_screen_name\":null,\"user\":{\"id\":376585411,\"id_str\":\"376585411\",\"name\":\"Dart Language\",\"screen_name\":\"dart_lang\",\"location\":\"\",\"description\":\"A client-optimized language for fast apps on any platform\",\"url\":\"https:\\/\\/t.co\\/FjOTI9dOPj\",\"entities\":{\"url\":{\"urls\":[{\"url\":\"https:\\/\\/t.co\\/FjOTI9dOPj\",\"expanded_url\":\"http:\\/\\/dart.dev\",\"display_url\":\"dart.dev\",\"indices\":[0,23]}]},\"description\":{\"urls\":[]}},\"protected\":false,\"followers_count\":41124,\"friends_count\":52,\"listed_count\":685,\"created_at\":\"Tue Sep 20 04:21:29 +0000 2011\",\"favourites_count\":246,\"utc_offset\":null,\"time_zone\":null,\"geo_enabled\":true,\"verified\":false,\"statuses_count\":1662,\"lang\":null,\"contributors_enabled\":false,\"is_translator\":false,\"is_translation_enabled\":false,\"profile_background_color\":\"FFFFFF\",\"profile_background_image_url\":\"http:\\/\\/abs.twimg.com\\/images\\/themes\\/theme1\\/bg.png\",\"profile_background_image_url_https\":\"https:\\/\\/abs.twimg.com\\/images\\/themes\\/theme1\\/bg.png\",\"profile_background_tile\":false,\"profile_image_url\":\"http:\\/\\/pbs.twimg.com\\/profile_images\\/993555605078994945\\/Yr-pWI4G_normal.jpg\",\"profile_image_url_https\":\"https:\\/\\/pbs.twimg.com\\/profile_images\\/993555605078994945\\/Yr-pWI4G_normal.jpg\",\"profile_banner_url\":\"https:\\/\\/pbs.twimg.com\\/profile_banners\\/376585411\\/1557177130\",\"profile_link_color\":\"0081C6\",\"profile_sidebar_border_color\":\"FFFFFF\",\"profile_sidebar_fill_color\":\"F2F2F2\",\"profile_text_color\":\"000000\",\"profile_use_background_image\":false,\"has_extended_profile\":false,\"default_profile\":false,\"default_profile_image\":false,\"following\":true,\"follow_request_sent\":false,\"notifications\":false,\"translator_type\":\"none\"},\"geo\":null,\"coordinates\":null,\"place\":null,\"contributors\":null,\"is_quote_status\":false,\"retweet_count\":45,\"favorite_count\":212,\"favorited\":true,\"retweeted\":false,\"possibly_sensitive\":false,\"lang\":\"en\"}''';

const _destroyFavoriteResponse =
    '''{\"created_at\":\"Mon Dec 23 21:30:01 +0000 2019\",\"id\":1209224666646274048,\"id_str\":\"1209224666646274048\",\"full_text\":\"\\ud83c\\udf89Dart has added a new feature called Extension Methods. \\u26a1\\n\\nNow you can add functionality to existing libraries. \\ud83d\\udcc1\\n \\nWatch here \\u2192  https:\\/\\/t.co\\/bYcGRLBwbO https:\\/\\/t.co\\/7LvVNVBN4X\",\"truncated\":false,\"display_text_range\":[0,153],\"entities\":{\"hashtags\":[],\"symbols\":[],\"user_mentions\":[],\"urls\":[{\"url\":\"https:\\/\\/t.co\\/bYcGRLBwbO\",\"expanded_url\":\"https:\\/\\/goo.gle\\/399jCKI\",\"display_url\":\"goo.gle\\/399jCKI\",\"indices\":[130,153]}],\"media\":[{\"id\":1209224663794159616,\"id_str\":\"1209224663794159616\",\"indices\":[154,177],\"media_url\":\"http:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"media_url_https\":\"https:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"url\":\"https:\\/\\/t.co\\/7LvVNVBN4X\",\"display_url\":\"pic.twitter.com\\/7LvVNVBN4X\",\"expanded_url\":\"https:\\/\\/twitter.com\\/dart_lang\\/status\\/1209224666646274048\\/photo\\/1\",\"type\":\"photo\",\"sizes\":{\"small\":{\"w\":680,\"h\":383,\"resize\":\"fit\"},\"thumb\":{\"w\":150,\"h\":150,\"resize\":\"crop\"},\"medium\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"},\"large\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"}}}]},\"extended_entities\":{\"media\":[{\"id\":1209224663794159616,\"id_str\":\"1209224663794159616\",\"indices\":[154,177],\"media_url\":\"http:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"media_url_https\":\"https:\\/\\/pbs.twimg.com\\/media\\/EMgHbMsXkAAxWtU.jpg\",\"url\":\"https:\\/\\/t.co\\/7LvVNVBN4X\",\"display_url\":\"pic.twitter.com\\/7LvVNVBN4X\",\"expanded_url\":\"https:\\/\\/twitter.com\\/dart_lang\\/status\\/1209224666646274048\\/photo\\/1\",\"type\":\"photo\",\"sizes\":{\"small\":{\"w\":680,\"h\":383,\"resize\":\"fit\"},\"thumb\":{\"w\":150,\"h\":150,\"resize\":\"crop\"},\"medium\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"},\"large\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"}}}]},\"source\":\"\\u003ca href=\\\"https:\\/\\/www.sprinklr.com\\\" rel=\\\"nofollow\\\"\\u003eSprinklr\\u003c\\/a\\u003e\",\"in_reply_to_status_id\":null,\"in_reply_to_status_id_str\":null,\"in_reply_to_user_id\":null,\"in_reply_to_user_id_str\":null,\"in_reply_to_screen_name\":null,\"user\":{\"id\":376585411,\"id_str\":\"376585411\",\"name\":\"Dart Language\",\"screen_name\":\"dart_lang\",\"location\":\"\",\"description\":\"A client-optimized language for fast apps on any platform\",\"url\":\"https:\\/\\/t.co\\/FjOTI9dOPj\",\"entities\":{\"url\":{\"urls\":[{\"url\":\"https:\\/\\/t.co\\/FjOTI9dOPj\",\"expanded_url\":\"http:\\/\\/dart.dev\",\"display_url\":\"dart.dev\",\"indices\":[0,23]}]},\"description\":{\"urls\":[]}},\"protected\":false,\"followers_count\":41124,\"friends_count\":52,\"listed_count\":685,\"created_at\":\"Tue Sep 20 04:21:29 +0000 2011\",\"favourites_count\":246,\"utc_offset\":null,\"time_zone\":null,\"geo_enabled\":true,\"verified\":false,\"statuses_count\":1662,\"lang\":null,\"contributors_enabled\":false,\"is_translator\":false,\"is_translation_enabled\":false,\"profile_background_color\":\"FFFFFF\",\"profile_background_image_url\":\"http:\\/\\/abs.twimg.com\\/images\\/themes\\/theme1\\/bg.png\",\"profile_background_image_url_https\":\"https:\\/\\/abs.twimg.com\\/images\\/themes\\/theme1\\/bg.png\",\"profile_background_tile\":false,\"profile_image_url\":\"http:\\/\\/pbs.twimg.com\\/profile_images\\/993555605078994945\\/Yr-pWI4G_normal.jpg\",\"profile_image_url_https\":\"https:\\/\\/pbs.twimg.com\\/profile_images\\/993555605078994945\\/Yr-pWI4G_normal.jpg\",\"profile_banner_url\":\"https:\\/\\/pbs.twimg.com\\/profile_banners\\/376585411\\/1557177130\",\"profile_link_color\":\"0081C6\",\"profile_sidebar_border_color\":\"FFFFFF\",\"profile_sidebar_fill_color\":\"F2F2F2\",\"profile_text_color\":\"000000\",\"profile_use_background_image\":false,\"has_extended_profile\":false,\"default_profile\":false,\"default_profile_image\":false,\"following\":true,\"follow_request_sent\":false,\"notifications\":false,\"translator_type\":\"none\"},\"geo\":null,\"coordinates\":null,\"place\":null,\"contributors\":null,\"is_quote_status\":false,\"retweet_count\":45,\"favorite_count\":211,\"favorited\":false,\"retweeted\":false,\"possibly_sensitive\":false,\"lang\":\"en\"}''';

const _listFavoritesResponse =
    '''[{\"created_at\":\"Thu Nov 21 13:26:38 +0000 2019\",\"id\":1197506605518139397,\"id_str\":\"1197506605518139397\",\"full_text\":\"hello\",\"truncated\":false,\"display_text_range\":[0,5],\"entities\":{\"hashtags\":[],\"symbols\":[],\"user_mentions\":[],\"urls\":[]},\"source\":\"\\u003ca href=\\\"http:\\/\\/robertodoering.com\\\" rel=\\\"nofollow\\\"\\u003eHarpy for Twitter\\u003c\\/a\\u003e\",\"in_reply_to_status_id\":null,\"in_reply_to_status_id_str\":null,\"in_reply_to_user_id\":null,\"in_reply_to_user_id_str\":null,\"in_reply_to_screen_name\":null,\"user\":{\"id\":1068105113284300800,\"id_str\":\"1068105113284300800\",\"name\":\"Harpy App\",\"screen_name\":\"harpy_app\",\"location\":\"North Pole, AK\",\"description\":\"please don't hurt me\",\"url\":\"https:\\/\\/t.co\\/cHZdP4MpC4\",\"entities\":{\"url\":{\"urls\":[{\"url\":\"https:\\/\\/t.co\\/cHZdP4MpC4\",\"expanded_url\":\"http:\\/\\/google.com\",\"display_url\":\"google.com\",\"indices\":[0,23]}]},\"description\":{\"urls\":[]}},\"protected\":false,\"followers_count\":1,\"friends_count\":10,\"listed_count\":0,\"created_at\":\"Thu Nov 29 11:31:18 +0000 2018\",\"favourites_count\":14,\"utc_offset\":null,\"time_zone\":null,\"geo_enabled\":false,\"verified\":false,\"statuses_count\":45,\"lang\":null,\"contributors_enabled\":false,\"is_translator\":false,\"is_translation_enabled\":false,\"profile_background_color\":\"000000\",\"profile_background_image_url\":\"http:\\/\\/abs.twimg.com\\/images\\/themes\\/theme1\\/bg.png\",\"profile_background_image_url_https\":\"https:\\/\\/abs.twimg.com\\/images\\/themes\\/theme1\\/bg.png\",\"profile_background_tile\":false,\"profile_image_url\":\"http:\\/\\/abs.twimg.com\\/sticky\\/default_profile_images\\/default_profile_normal.png\",\"profile_image_url_https\":\"https:\\/\\/abs.twimg.com\\/sticky\\/default_profile_images\\/default_profile_normal.png\",\"profile_link_color\":\"981CEB\",\"profile_sidebar_border_color\":\"000000\",\"profile_sidebar_fill_color\":\"000000\",\"profile_text_color\":\"000000\",\"profile_use_background_image\":false,\"has_extended_profile\":true,\"default_profile\":false,\"default_profile_image\":true,\"following\":false,\"follow_request_sent\":false,\"notifications\":false,\"translator_type\":\"none\"},\"geo\":null,\"coordinates\":null,\"place\":null,\"contributors\":null,\"is_quote_status\":false,\"retweet_count\":0,\"favorite_count\":1,\"favorited\":true,\"retweeted\":false,\"lang\":\"en\"},{\"created_at\":\"Sun Sep 22 20:23:19 +0000 2019\",\"id\":1175868196622098434,\"id_str\":\"1175868196622098434\",\"full_text\":\"does this still work\",\"truncated\":false,\"display_text_range\":[0,20],\"entities\":{\"hashtags\":[],\"symbols\":[],\"user_mentions\":[],\"urls\":[]},\"source\":\"\\u003ca href=\\\"http:\\/\\/robertodoering.com\\\" rel=\\\"nofollow\\\"\\u003eHarpy for Twitter\\u003c\\/a\\u003e\",\"in_reply_to_status_id\":null,\"in_reply_to_status_id_str\":null,\"in_reply_to_user_id\":null,\"in_reply_to_user_id_str\":null,\"in_reply_to_screen_name\":null,\"user\":{\"id\":1068105113284300800,\"id_str\":\"1068105113284300800\",\"name\":\"Harpy App\",\"screen_name\":\"harpy_app\",\"location\":\"North Pole, AK\",\"description\":\"please don't hurt me\",\"url\":\"https:\\/\\/t.co\\/cHZdP4MpC4\",\"entities\":{\"url\":{\"urls\":[{\"url\":\"https:\\/\\/t.co\\/cHZdP4MpC4\",\"expanded_url\":\"http:\\/\\/google.com\",\"display_url\":\"google.com\",\"indices\":[0,23]}]},\"description\":{\"urls\":[]}},\"protected\":false,\"followers_count\":1,\"friends_count\":10,\"listed_count\":0,\"created_at\":\"Thu Nov 29 11:31:18 +0000 2018\",\"favourites_count\":14,\"utc_offset\":null,\"time_zone\":null,\"geo_enabled\":false,\"verified\":false,\"statuses_count\":45,\"lang\":null,\"contributors_enabled\":false,\"is_translator\":false,\"is_translation_enabled\":false,\"profile_background_color\":\"000000\",\"profile_background_image_url\":\"http:\\/\\/abs.twimg.com\\/images\\/themes\\/theme1\\/bg.png\",\"profile_background_image_url_https\":\"https:\\/\\/abs.twimg.com\\/images\\/themes\\/theme1\\/bg.png\",\"profile_background_tile\":false,\"profile_image_url\":\"http:\\/\\/abs.twimg.com\\/sticky\\/default_profile_images\\/default_profile_normal.png\",\"profile_image_url_https\":\"https:\\/\\/abs.twimg.com\\/sticky\\/default_profile_images\\/default_profile_normal.png\",\"profile_link_color\":\"981CEB\",\"profile_sidebar_border_color\":\"000000\",\"profile_sidebar_fill_color\":\"000000\",\"profile_text_color\":\"000000\",\"profile_use_background_image\":false,\"has_extended_profile\":true,\"default_profile\":false,\"default_profile_image\":true,\"following\":false,\"follow_request_sent\":false,\"notifications\":false,\"translator_type\":\"none\"},\"geo\":null,\"coordinates\":null,\"place\":null,\"contributors\":null,\"is_quote_status\":false,\"retweet_count\":0,\"favorite_count\":1,\"favorited\":true,\"retweeted\":false,\"lang\":\"en\"},{\"created_at\":\"Wed Sep 11 15:00:01 +0000 2019\",\"id\":1171800569742331910,\"id_str\":\"1171800569742331910\",\"full_text\":\"\\ud83c\\udf89Flutter 1.9 upgrade goodies!\\n \\niOS style updates, support for additional locales, Dart 2.5 with the foreign function interface and more built-in widgets:\\n \\n\\u2705SelectableText widget\\n\\u2705ColorFiltered widget\\n\\u2705New error message format\\n \\nLearn more here \\u2192 https:\\/\\/t.co\\/bm6aGsOR2u https:\\/\\/t.co\\/5NzW8iPhEf\",\"truncated\":false,\"display_text_range\":[0,271],\"entities\":{\"hashtags\":[],\"symbols\":[],\"user_mentions\":[],\"urls\":[{\"url\":\"https:\\/\\/t.co\\/bm6aGsOR2u\",\"expanded_url\":\"https:\\/\\/goo.gle\\/2Na6Fsk\",\"display_url\":\"goo.gle\\/2Na6Fsk\",\"indices\":[248,271]}],\"media\":[{\"id\":1171800567879995398,\"id_str\":\"1171800567879995398\",\"indices\":[272,295],\"media_url\":\"http:\\/\\/pbs.twimg.com\\/media\\/EEMSaHQWkAY23uI.jpg\",\"media_url_https\":\"https:\\/\\/pbs.twimg.com\\/media\\/EEMSaHQWkAY23uI.jpg\",\"url\":\"https:\\/\\/t.co\\/5NzW8iPhEf\",\"display_url\":\"pic.twitter.com\\/5NzW8iPhEf\",\"expanded_url\":\"https:\\/\\/twitter.com\\/FlutterDev\\/status\\/1171800569742331910\\/photo\\/1\",\"type\":\"photo\",\"sizes\":{\"small\":{\"w\":680,\"h\":383,\"resize\":\"fit\"},\"thumb\":{\"w\":150,\"h\":150,\"resize\":\"crop\"},\"large\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"},\"medium\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"}}}]},\"extended_entities\":{\"media\":[{\"id\":1171800567879995398,\"id_str\":\"1171800567879995398\",\"indices\":[272,295],\"media_url\":\"http:\\/\\/pbs.twimg.com\\/media\\/EEMSaHQWkAY23uI.jpg\",\"media_url_https\":\"https:\\/\\/pbs.twimg.com\\/media\\/EEMSaHQWkAY23uI.jpg\",\"url\":\"https:\\/\\/t.co\\/5NzW8iPhEf\",\"display_url\":\"pic.twitter.com\\/5NzW8iPhEf\",\"expanded_url\":\"https:\\/\\/twitter.com\\/FlutterDev\\/status\\/1171800569742331910\\/photo\\/1\",\"type\":\"photo\",\"sizes\":{\"small\":{\"w\":680,\"h\":383,\"resize\":\"fit\"},\"thumb\":{\"w\":150,\"h\":150,\"resize\":\"crop\"},\"large\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"},\"medium\":{\"w\":1024,\"h\":576,\"resize\":\"fit\"}}}]},\"source\":\"\\u003ca href=\\\"https:\\/\\/www.sprinklr.com\\\" rel=\\\"nofollow\\\"\\u003eSprinklr\\u003c\\/a\\u003e\",\"in_reply_to_status_id\":null,\"in_reply_to_status_id_str\":null,\"in_reply_to_user_id\":null,\"in_reply_to_user_id_str\":null,\"in_reply_to_screen_name\":null,\"user\":{\"id\":420730316,\"id_str\":\"420730316\",\"name\":\"Flutter\",\"screen_name\":\"FlutterDev\",\"location\":\"\",\"description\":\"Google\\u2019s UI toolkit to build apps for mobile, web, & desktop from a single codebase \\/\\/\",\"url\":\"https:\\/\\/t.co\\/vAf0IEGV9l\",\"entities\":{\"url\":{\"urls\":[{\"url\":\"https:\\/\\/t.co\\/vAf0IEGV9l\",\"expanded_url\":\"https:\\/\\/flutter.dev\",\"display_url\":\"flutter.dev\",\"indices\":[0,23]}]},\"description\":{\"urls\":[]}},\"protected\":false,\"followers_count\":96522,\"friends_count\":35,\"listed_count\":899,\"created_at\":\"Fri Nov 25 01:07:12 +0000 2011\",\"favourites_count\":706,\"utc_offset\":null,\"time_zone\":null,\"geo_enabled\":false,\"verified\":true,\"statuses_count\":1073,\"lang\":null,\"contributors_enabled\":false,\"is_translator\":false,\"is_translation_enabled\":false,\"profile_background_color\":\"000000\",\"profile_background_image_url\":\"http:\\/\\/abs.twimg.com\\/images\\/themes\\/theme1\\/bg.png\",\"profile_background_image_url_https\":\"https:\\/\\/abs.twimg.com\\/images\\/themes\\/theme1\\/bg.png\",\"profile_background_tile\":false,\"profile_image_url\":\"http:\\/\\/pbs.twimg.com\\/profile_images\\/1187814172307800064\\/MhnwJbxw_normal.jpg\",\"profile_image_url_https\":\"https:\\/\\/pbs.twimg.com\\/profile_images\\/1187814172307800064\\/MhnwJbxw_normal.jpg\",\"profile_banner_url\":\"https:\\/\\/pbs.twimg.com\\/profile_banners\\/420730316\\/1578350457\",\"profile_link_color\":\"29B6F6\",\"profile_sidebar_border_color\":\"000000\",\"profile_sidebar_fill_color\":\"000000\",\"profile_text_color\":\"000000\",\"profile_use_background_image\":false,\"has_extended_profile\":false,\"default_profile\":false,\"default_profile_image\":false,\"following\":true,\"follow_request_sent\":false,\"notifications\":false,\"translator_type\":\"none\"},\"geo\":null,\"coordinates\":null,\"place\":null,\"contributors\":null,\"is_quote_status\":false,\"retweet_count\":142,\"favorite_count\":496,\"favorited\":true,\"retweeted\":false,\"possibly_sensitive\":false,\"lang\":\"en\"}]''';
